@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: document summary processing, available outputs and metadata
 
@@ -56,33 +56,33 @@ module SiSU_Translate
     def initialize(md,doc_lang,trans_str='')
       @md,@doc_lang,@trans_str=md,doc_lang,trans_str
       @lang_class=case @doc_lang
-      when /American/i:                  English.new(md,doc_lang,trans_str) 
-      when /English/i:                   English.new(md,doc_lang,trans_str) 
-      when /French/i:                    French.new(md,doc_lang,trans_str) 
-      when /German/i:                    German.new(md,doc_lang,trans_str)  
-      when /Italian/i:                   Italian.new(md,doc_lang,trans_str)  
-      when /Spanish/i:                   Spanish.new(md,doc_lang,trans_str)  
-      when /Brazilian(?: Portuguese)?/i: Portuguese.new(md,doc_lang,trans_str)  
-      when /Portuguese/i:                Portuguese.new(md,doc_lang,trans_str) 
-      when /Swedish/i:                   Swedish.new(md,doc_lang,trans_str) 
-      when /Danish/i:                    Danish.new(md,doc_lang,trans_str)  
-      when /Finnish/i:                   Finnish.new(md,doc_lang,trans_str) 
-      when /Norwegian/i:                 Norwegian.new(md,doc_lang,trans_str) 
-      when /Icelandic/i:                 Icelandic.new(md,doc_lang,trans_str) 
-      when /Dutch/i:                     Dutch.new(md,doc_lang,trans_str) 
-      when /Estonian/i:                  Estonian.new(md,doc_lang,trans_str) 
-      when /Hungarian/i:                 Hungarian.new(md,doc_lang,trans_str) 
-      when /Polish/i:                    Polish.new(md,doc_lang,trans_str) 
-      when /Romanian/i:                  Romanian.new(md,doc_lang,trans_str) 
-      when /Russian/i:                   Russian.new(md,doc_lang,trans_str) 
-      when /Greek/i:                     Greek.new(md,doc_lang,trans_str) 
-      when /Ukranian/i:                  Ukranian.new(md,doc_lang,trans_str) 
-      when /Turkish/i:                   Turkish.new(md,doc_lang,trans_str) 
-      when /Slovenian/i:                 Slovenian.new(md,doc_lang,trans_str) 
-      when /Croatian/i:                  Croatian.new(md,doc_lang,trans_str) 
-      when /Slovak(?:ian)?/i:            Slovak.new(md,doc_lang,trans_str) 
-      when /Czech/i:                     Czech.new(md,doc_lang,trans_str) 
-      when /Bulgarian/i:                 Bulgarian.new(md,doc_lang,trans_str) 
+      when /American/i;                  English.new(md,doc_lang,trans_str) 
+      when /English/i;                   English.new(md,doc_lang,trans_str) 
+      when /French/i;                    French.new(md,doc_lang,trans_str) 
+      when /German/i;                    German.new(md,doc_lang,trans_str)  
+      when /Italian/i;                   Italian.new(md,doc_lang,trans_str)  
+      when /Spanish/i;                   Spanish.new(md,doc_lang,trans_str)  
+      when /Brazilian(?: Portuguese)?/i; Portuguese.new(md,doc_lang,trans_str)  
+      when /Portuguese/i;                Portuguese.new(md,doc_lang,trans_str) 
+      when /Swedish/i;                   Swedish.new(md,doc_lang,trans_str) 
+      when /Danish/i;                    Danish.new(md,doc_lang,trans_str)  
+      when /Finnish/i;                   Finnish.new(md,doc_lang,trans_str) 
+      when /Norwegian/i;                 Norwegian.new(md,doc_lang,trans_str) 
+      when /Icelandic/i;                 Icelandic.new(md,doc_lang,trans_str) 
+      when /Dutch/i;                     Dutch.new(md,doc_lang,trans_str) 
+      when /Estonian/i;                  Estonian.new(md,doc_lang,trans_str) 
+      when /Hungarian/i;                 Hungarian.new(md,doc_lang,trans_str) 
+      when /Polish/i;                    Polish.new(md,doc_lang,trans_str) 
+      when /Romanian/i;                  Romanian.new(md,doc_lang,trans_str) 
+      when /Russian/i;                   Russian.new(md,doc_lang,trans_str) 
+      when /Greek/i;                     Greek.new(md,doc_lang,trans_str) 
+      when /Ukranian/i;                  Ukranian.new(md,doc_lang,trans_str) 
+      when /Turkish/i;                   Turkish.new(md,doc_lang,trans_str) 
+      when /Slovenian/i;                 Slovenian.new(md,doc_lang,trans_str) 
+      when /Croatian/i;                  Croatian.new(md,doc_lang,trans_str) 
+      when /Slovak(?:ian)?/i;            Slovak.new(md,doc_lang,trans_str) 
+      when /Czech/i;                     Czech.new(md,doc_lang,trans_str) 
+      when /Bulgarian/i;                 Bulgarian.new(md,doc_lang,trans_str) 
       else                               English.new(md,doc_lang,trans_str) 
       end
     end
@@ -259,36 +259,36 @@ module SiSU_Translate
     end
     def language_list
       lang=case @trans_str
-      when /American/i:                  'American English'
-      when /English/i:                   'English'
-      when /French/i:                    'français'
-      when /German/i:                    'Deutsch'
-      when /Italian/i:                   'Italiano'
-      when /Spanish/i:                   'español'
-      when /Brazilian(?: Portuguese)?/i: 'Brazilian Português'
-      when /Portuguese/i:                'Português'
-      when /Swedish/i:                   'svenska'
-      when /Danish/i:                    'dansk'
-      when /Finnish/i:                   'suomi'
-      when /Norwegian/i:                 'norsk'             #check uppercase
-      when /Icelandic/i:                 'Icelandic'
-      when /Dutch/i:                     'Nederlands'
-      when /Estonian/i:                  'Estonian'
-      when /Hungarian/i:                 'Hungarian'
-      when /Polish/i:                    'polski'
-      when /Romanian/i:                  'română'
-      when /Russian/i:                   'Русский (Russkij)'
-      when /Greek/i:                     'Ελληνικά (Ellinika)'
-      when /Ukranian/i:                  'українська (ukrajins\'ka)'
-      when /Turkish/i:                   'Türkçe'
-      when /Slovenian/i:                 'Slovenian'
-      when /Croatian/i:                  'Croatian'
-      when /Slovak(?:ian)?/i:            'slovensky'            #slovensky ?
-      when /Czech/i:                     'česky'
-      when /Bulgarian/i:                 'Български (Bəlgarski)'
-      when /Japanese/i:                  '日本語 (Nihongo)'
-      when /Korean/i:                    '한국어 (Hangul)'
-      #when /Catalan/i:                   'català'
+      when /American/i;                  'American English'
+      when /English/i;                   'English'
+      when /French/i;                    'français'
+      when /German/i;                    'Deutsch'
+      when /Italian/i;                   'Italiano'
+      when /Spanish/i;                   'español'
+      when /Brazilian(?: Portuguese)?/i; 'Brazilian Português'
+      when /Portuguese/i;                'Português'
+      when /Swedish/i;                   'svenska'
+      when /Danish/i;                    'dansk'
+      when /Finnish/i;                   'suomi'
+      when /Norwegian/i;                 'norsk'
+      when /Icelandic/i;                 'Icelandic'
+      when /Dutch/i;                     'Nederlands'
+      when /Estonian/i;                  'Estonian'
+      when /Hungarian/i;                 'Hungarian'
+      when /Polish/i;                    'polski'
+      when /Romanian/i;                  'română'
+      when /Russian/i;                   'Русский (Russkij)'
+      when /Greek/i;                     'Ελληνικά (Ellinika)'
+      when /Ukranian/i;                  'українська (ukrajins\'ka)'
+      when /Turkish/i;                   'Türkçe'
+      when /Slovenian/i;                 'Slovenian'
+      when /Croatian/i;                  'Croatian'
+      when /Slovak(?:ian)?/i;            'slovensky'            #slovensky ?
+      when /Czech/i;                     'česky'
+      when /Bulgarian/i;                 'Български (Bəlgarski)'
+      when /Japanese/i;                  '日本語 (Nihongo)'
+      when /Korean/i;                    '한국어 (Hangul)'
+      #when /Catalan/i;                   'català'
       else                               'English'
       end
       #check on 中文  and عربي
@@ -462,33 +462,33 @@ module SiSU_Translate
     end
     def language_list_translated
       lang=case @trans_str
-      when /American/i:                  'American English'
-      when /English/i:                   'English'
-      when /French/i:                    'French'
-      when /German/i:                    'German'
-      when /Italian/i:                   'Italian'
-      when /Spanish/i:                   'Spanish'
-      when /Brazilian(?: Portuguese)?/i: 'Brazilian Portuguese'
-      when /Portuguese/i:                'Portuguese'
-      when /Swedish/i:                   'Swedish'
-      when /Danish/i:                    'Danish'
-      when /Finnish/i:                   'Finnish'
-      when /Norwegian/i:                 'Norwegian'
-      when /Icelandic/i:                 'Icelandic'
-      when /Dutch/i:                     'Dutch'
-      when /Estonian/i:                  'Estonian'
-      when /Hungarian/i:                 'Hungarian'
-      when /Polish/i:                    'Polish'
-      when /Romanian/i:                  'Romanian'
-      when /Russian/i:                   'Russian'
-      when /Greek/i:                     'Greek'
-      when /Ukranian/i:                  'Ukranian'
-      when /Turkish/i:                   'Turkish'
-      when /Slovenian/i:                 'Slovenian'
-      when /Croatian/i:                  'Croatian'
-      when /Slovak(?:ian)?/i:            'Slovakian'
-      when /Czech/i:                     'Czech'
-      when /Bulgarian/i:                 'Bulgarian'
+      when /American/i;                  'American English'
+      when /English/i;                   'English'
+      when /French/i;                    'French'
+      when /German/i;                    'German'
+      when /Italian/i;                   'Italian'
+      when /Spanish/i;                   'Spanish'
+      when /Brazilian(?: Portuguese)?/i; 'Brazilian Portuguese'
+      when /Portuguese/i;                'Portuguese'
+      when /Swedish/i;                   'Swedish'
+      when /Danish/i;                    'Danish'
+      when /Finnish/i;                   'Finnish'
+      when /Norwegian/i;                 'Norwegian'
+      when /Icelandic/i;                 'Icelandic'
+      when /Dutch/i;                     'Dutch'
+      when /Estonian/i;                  'Estonian'
+      when /Hungarian/i;                 'Hungarian'
+      when /Polish/i;                    'Polish'
+      when /Romanian/i;                  'Romanian'
+      when /Russian/i;                   'Russian'
+      when /Greek/i;                     'Greek'
+      when /Ukranian/i;                  'Ukranian'
+      when /Turkish/i;                   'Turkish'
+      when /Slovenian/i;                 'Slovenian'
+      when /Croatian/i;                  'Croatian'
+      when /Slovak(?:ian)?/i;            'Slovakian'
+      when /Czech/i;                     'Czech'
+      when /Bulgarian/i;                 'Bulgarian'
       else @trans_str
       end
     end
@@ -661,33 +661,33 @@ module SiSU_Translate
     end
     def language_list_translated
       lang=case @trans_str
-      when /American/i:                  'Anglais americain'
-      when /English/i:                   'Anglais'
-      when /French/i:                    'Français'
-      when /German/i:                    'Allemand'
-      when /Italian/i:                   'Italien'
-      when /Spanish/i:                   'Espagnol'
-      when /Brazilian(?: Portuguese)?/i: 'Portugais brésilien'
-      when /Portuguese/i:                'Portugais'
-      when /Swedish/i:                   'Suédois'
-      when /Danish/i:                    'Danois'
-      when /Finnish/i:                   'Finnois'
-      when /Norwegian/i:                 'Norvégien'
-      when /Icelandic/i:                 'Islandais'
-      when /Dutch/i:                     'Néerlandais'
-      when /Estonian/i:                  'Estonien'
-      when /Hungarian/i:                 'Hongrois'
-      when /Polish/i:                    'Polonais'
-      when /Romanian/i:                  'Roumain'
-      when /Russian/i:                   'Russe'
-      when /Greek/i:                     'Grec'
-      when /Ukranian/i:                  'Ukrainien'
-      when /Turkish/i:                   'Turc'
-      when /Slovenian/i:                 'Slovène'
-      when /Croatian/i:                  'Croate'
-      when /Slovak(?:ian)?/i:            'Slovaque'
-      when /Czech/i:                     'Tcheque'
-      when /Bulgarian/i:                 'Bulgare'
+      when /American/i;                  'Anglais americain'
+      when /English/i;                   'Anglais'
+      when /French/i;                    'Français'
+      when /German/i;                    'Allemand'
+      when /Italian/i;                   'Italien'
+      when /Spanish/i;                   'Espagnol'
+      when /Brazilian(?: Portuguese)?/i; 'Portugais brésilien'
+      when /Portuguese/i;                'Portugais'
+      when /Swedish/i;                   'Suédois'
+      when /Danish/i;                    'Danois'
+      when /Finnish/i;                   'Finnois'
+      when /Norwegian/i;                 'Norvégien'
+      when /Icelandic/i;                 'Islandais'
+      when /Dutch/i;                     'Néerlandais'
+      when /Estonian/i;                  'Estonien'
+      when /Hungarian/i;                 'Hongrois'
+      when /Polish/i;                    'Polonais'
+      when /Romanian/i;                  'Roumain'
+      when /Russian/i;                   'Russe'
+      when /Greek/i;                     'Grec'
+      when /Ukranian/i;                  'Ukrainien'
+      when /Turkish/i;                   'Turc'
+      when /Slovenian/i;                 'Slovène'
+      when /Croatian/i;                  'Croate'
+      when /Slovak(?:ian)?/i;            'Slovaque'
+      when /Czech/i;                     'Tcheque'
+      when /Bulgarian/i;                 'Bulgare'
       else @trans_str
       end
     end
@@ -860,33 +860,33 @@ module SiSU_Translate
     end
     def language_list_translated
       lang=case @trans_str
-      when /American/i:                  'Amerikanisch-Englisch'
-      when /English/i:                   'Englisch'
-      when /French/i:                    'Französisch'
-      when /German/i:                    'Deutsch'
-      when /Italian/i:                   'Italienisch'
-      when /Spanish/i:                   'Spanisch'
-      when /Brazilian(?: Portuguese)?/i: 'Brasilianisch-Portugiesisch'
-      when /Portuguese/i:                'Portugiesisch'
-      when /Swedish/i:                   'Schwedisch'
-      when /Danish/i:                    'Dänisch'
-      when /Finnish/i:                   'Finnisch'
-      when /Norwegian/i:                 'Norwegisch'
-      when /Icelandic/i:                 'Isländisch'
-      when /Dutch/i:                     'Niederländisch'
-      when /Estonian/i:                  'Estnisch'
-      when /Hungarian/i:                 'Ungarisch'
-      when /Polish/i:                    'Polnisch'
-      when /Romanian/i:                  'Rumänisch'
-      when /Russian/i:                   'Russisch'
-      when /Greek/i:                     'Griechisch'
-      when /Ukranian/i:                  'Ukrainisch'
-      when /Turkish/i:                   'Türkisch'
-      when /Slovenian/i:                 'Slovenisch'
-      when /Croatian/i:                  'Kroatisch'
-      when /Slovak(?:ian)?/i:            'Slovakisch'
-      when /Czech/i:                     'Tschechisch'
-      when /Bulgarian/i:                 'Bulgarisch'
+      when /American/i;                  'Amerikanisch-Englisch'
+      when /English/i;                   'Englisch'
+      when /French/i;                    'Französisch'
+      when /German/i;                    'Deutsch'
+      when /Italian/i;                   'Italienisch'
+      when /Spanish/i;                   'Spanisch'
+      when /Brazilian(?: Portuguese)?/i; 'Brasilianisch-Portugiesisch'
+      when /Portuguese/i;                'Portugiesisch'
+      when /Swedish/i;                   'Schwedisch'
+      when /Danish/i;                    'Dänisch'
+      when /Finnish/i;                   'Finnisch'
+      when /Norwegian/i;                 'Norwegisch'
+      when /Icelandic/i;                 'Isländisch'
+      when /Dutch/i;                     'Niederländisch'
+      when /Estonian/i;                  'Estnisch'
+      when /Hungarian/i;                 'Ungarisch'
+      when /Polish/i;                    'Polnisch'
+      when /Romanian/i;                  'Rumänisch'
+      when /Russian/i;                   'Russisch'
+      when /Greek/i;                     'Griechisch'
+      when /Ukranian/i;                  'Ukrainisch'
+      when /Turkish/i;                   'Türkisch'
+      when /Slovenian/i;                 'Slovenisch'
+      when /Croatian/i;                  'Kroatisch'
+      when /Slovak(?:ian)?/i;            'Slovakisch'
+      when /Czech/i;                     'Tschechisch'
+      when /Bulgarian/i;                 'Bulgarisch'
       else @trans_str
       end
     end
@@ -1059,33 +1059,33 @@ module SiSU_Translate
    end
    def language_list_translated
      lang=case @trans_str
-     when /American/i:                  'Inglés Americano'
-     when /English/i:                   'Inglés'
-     when /French/i:                    'Francés'
-     when /German/i:                    'Alemán'
-     when /Italian/i:                   'Italiano'
-     when /Spanish/i:                   'Español'
-     when /Brazilian(?: Portuguese)?/i: 'Portugués de Brasil'
-     when /Portuguese/i:                'Portugués'
-     when /Swedish/i:                   'Sueco'
-     when /Danish/i:                    'Danés'
-     when /Finnish/i:                   'Finés'
-     when /Norwegian/i:                 'Noruego'
-     when /Icelandic/i:                 'Islandés'
-     when /Dutch/i:                     'Holandés'
-     when /Estonian/i:                  'Estonio'
-     when /Hungarian/i:                 'Húngaro'
-     when /Polish/i:                    'Polaco'
-     when /Romanian/i:                  'Rumano'
-     when /Russian/i:                   'Ruso'
-     when /Greek/i:                     'Griego'
-     when /Ukranian/i:                  'Ucraniano'
-     when /Turkish/i:                   'Turco'
-     when /Slovenian/i:                 'Eslovaco'
-     when /Croatian/i:                  'Croata'
-     when /Slovak(?:ian)?/i:            'Eslovaco'
-     when /Czech/i:                     'Checo'
-     when /Bulgarian/i:                 'Búlgaro'
+     when /American/i;                  'Inglés Americano'
+     when /English/i;                   'Inglés'
+     when /French/i;                    'Francés'
+     when /German/i;                    'Alemán'
+     when /Italian/i;                   'Italiano'
+     when /Spanish/i;                   'Español'
+     when /Brazilian(?: Portuguese)?/i; 'Portugués de Brasil'
+     when /Portuguese/i;                'Portugués'
+     when /Swedish/i;                   'Sueco'
+     when /Danish/i;                    'Danés'
+     when /Finnish/i;                   'Finés'
+     when /Norwegian/i;                 'Noruego'
+     when /Icelandic/i;                 'Islandés'
+     when /Dutch/i;                     'Holandés'
+     when /Estonian/i;                  'Estonio'
+     when /Hungarian/i;                 'Húngaro'
+     when /Polish/i;                    'Polaco'
+     when /Romanian/i;                  'Rumano'
+     when /Russian/i;                   'Ruso'
+     when /Greek/i;                     'Griego'
+     when /Ukranian/i;                  'Ucraniano'
+     when /Turkish/i;                   'Turco'
+     when /Slovenian/i;                 'Eslovaco'
+     when /Croatian/i;                  'Croata'
+     when /Slovak(?:ian)?/i;            'Eslovaco'
+     when /Czech/i;                     'Checo'
+     when /Bulgarian/i;                 'Búlgaro'
      else @trans_str
      end
    end
@@ -1258,33 +1258,33 @@ module SiSU_Translate
     end
     def language_list_translated
       lang=case @trans_str
-      when /American/i:                  'Inglese USA'
-      when /English/i:                   'Inglese'
-      when /French/i:                    'Francese'
-      when /German/i:                    'Tedesco'
-      when /Italian/i:                   'Italiano'
-      when /Spanish/i:                   'Spagnolo'
-      when /Brazilian(?: Portuguese)?/i: 'Portoguese (Brasile)'
-      when /Portuguese/i:                'Portoguese'
-      when /Swedish/i:                   'Svedese'
-      when /Danish/i:                    'Danese'
-      when /Finnish/i:                   'Finlandese'
-      when /Norwegian/i:                 'Norvegese'
-      when /Icelandic/i:                 'Islandese'
-      when /Dutch/i:                     'Olandese'
-      when /Estonian/i:                  'Estone'
-      when /Hungarian/i:                 'Ungherese'
-      when /Polish/i:                    'Polacco'
-      when /Romanian/i:                  'Romeno'
-      when /Russian/i:                   'Russo'
-      when /Greek/i:                     'Greco'
-      when /Ukranian/i:                  'Ucraino'
-      when /Turkish/i:                   'Turco'
-      when /Slovenian/i:                 'Sloveno'
-      when /Croatian/i:                  'Croato'
-      when /Slovak(?:ian)?/i:            'Slovacco'
-      when /Czech/i:                     'Ceco'
-      when /Bulgarian/i:                 'Bulgaro'
+      when /American/i;                  'Inglese USA'
+      when /English/i;                   'Inglese'
+      when /French/i;                    'Francese'
+      when /German/i;                    'Tedesco'
+      when /Italian/i;                   'Italiano'
+      when /Spanish/i;                   'Spagnolo'
+      when /Brazilian(?: Portuguese)?/i; 'Portoguese (Brasile)'
+      when /Portuguese/i;                'Portoguese'
+      when /Swedish/i;                   'Svedese'
+      when /Danish/i;                    'Danese'
+      when /Finnish/i;                   'Finlandese'
+      when /Norwegian/i;                 'Norvegese'
+      when /Icelandic/i;                 'Islandese'
+      when /Dutch/i;                     'Olandese'
+      when /Estonian/i;                  'Estone'
+      when /Hungarian/i;                 'Ungherese'
+      when /Polish/i;                    'Polacco'
+      when /Romanian/i;                  'Romeno'
+      when /Russian/i;                   'Russo'
+      when /Greek/i;                     'Greco'
+      when /Ukranian/i;                  'Ucraino'
+      when /Turkish/i;                   'Turco'
+      when /Slovenian/i;                 'Sloveno'
+      when /Croatian/i;                  'Croato'
+      when /Slovak(?:ian)?/i;            'Slovacco'
+      when /Czech/i;                     'Ceco'
+      when /Bulgarian/i;                 'Bulgaro'
       else @trans_str
       end
     end
@@ -1457,33 +1457,33 @@ module SiSU_Translate
     end
     def language_list_translated
       lang=case @trans_str
-      when /American/i:                  'Amerikanenglanti'
-      when /English/i:                   'Englanti'
-      when /French/i:                    'Ranska'
-      when /German/i:                    'Saksa'
-      when /Italian/i:                   'Italia'
-      when /Spanish/i:                   'Espanja'
-      when /Brazilian(?: Portuguese)?/i: 'Brasilian portugali'
-      when /Portuguese/i:                'Portugali'
-      when /Swedish/i:                   'Ruotsi'
-      when /Danish/i:                    'Tanska'
-      when /Finnish/i:                   'Suomi'
-      when /Norwegian/i:                 'Norja'
-      when /Icelandic/i:                 'Islanti'
-      when /Dutch/i:                     'Hollanti'
-      when /Estonian/i:                  'Viro'
-      when /Hungarian/i:                 'Unkari'
-      when /Polish/i:                    'Puola'
-      when /Romanian/i:                  'Romania'
-      when /Russian/i:                   'Venäjä'
-      when /Greek/i:                     'Kreikka'
-      when /Ukranian/i:                  'Ukraina'
-      when /Turkish/i:                   'Turkki'
-      when /Slovenian/i:                 'Slovenia'
-      when /Croatian/i:                  'Kroatia'
-      when /Slovak(?:ian)?/i:            'Slovakki'
-      when /Czech/i:                     'Tsekki'
-      when /Bulgarian/i:                 'Bulgaria'
+      when /American/i;                  'Amerikanenglanti'
+      when /English/i;                   'Englanti'
+      when /French/i;                    'Ranska'
+      when /German/i;                    'Saksa'
+      when /Italian/i;                   'Italia'
+      when /Spanish/i;                   'Espanja'
+      when /Brazilian(?: Portuguese)?/i; 'Brasilian portugali'
+      when /Portuguese/i;                'Portugali'
+      when /Swedish/i;                   'Ruotsi'
+      when /Danish/i;                    'Tanska'
+      when /Finnish/i;                   'Suomi'
+      when /Norwegian/i;                 'Norja'
+      when /Icelandic/i;                 'Islanti'
+      when /Dutch/i;                     'Hollanti'
+      when /Estonian/i;                  'Viro'
+      when /Hungarian/i;                 'Unkari'
+      when /Polish/i;                    'Puola'
+      when /Romanian/i;                  'Romania'
+      when /Russian/i;                   'Venäjä'
+      when /Greek/i;                     'Kreikka'
+      when /Ukranian/i;                  'Ukraina'
+      when /Turkish/i;                   'Turkki'
+      when /Slovenian/i;                 'Slovenia'
+      when /Croatian/i;                  'Kroatia'
+      when /Slovak(?:ian)?/i;            'Slovakki'
+      when /Czech/i;                     'Tsekki'
+      when /Bulgarian/i;                 'Bulgaria'
       else @trans_str
       end
     end
