@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: generates naive cgi search form for search of sisu database (pgsql sqlite)
 
@@ -53,34 +53,33 @@ module  SiSU_CGI_pgsql
   class SiSU_search_pgsql
     def initialize(opt,webserv)
       @opt,@webserv=opt,webserv
-      webrick_port=SiSU_Env::Info_dir.new.webrick_port
-      @port=case @opt.mod_s
-      when /--webserve?r?=webrick/
+      webrick_port=SiSU_Env::Info_env.new.webrick_port
+      @port=case @opt.mod.inspect
+      when /--webserve?r?[=-]webrick/
         @webrick_port=":#{webrick_port}"
         "        '#@webrick_port'\n"
       else
         @webrick_port=''
         "        ''\n"
       end
-      @url_base="#{SiSU_Env::Info_dir.new.webserv_url_base}/_sisu/image"
-      @env=SiSU_Env::Info_dir.new
+      @url_base="#{SiSU_Env::Info_env.new.url.webserv_base}/_sisu/image"
+      @env=SiSU_Env::Info_env.new
       @common=SiSU_CGI_sql::SiSU_CGI_common.new(@webserv,@opt.cmd,@port,@webrick_port,@url_base,@env)
     end
     def pgsql
-      serve=Array.new
-      Dir.foreach(@env.webserv_path) do |x| 
-        if x !~/^\./ and FileTest.directory?("#{@env.webserv_path}/#{x}"): serve << x unless x =~/^_\S+/ 
+      serve=[]
+      Dir.foreach(@env.path.webserv) do |x| 
+        if x !~/^\./ and FileTest.directory?("#{@env.path.webserv}/#{x}"); serve << x unless x =~/^_\S+/ 
         end
       end
       serve.sort!
-      f1,f2,f3=Array.new,Array.new,Array.new
-      #f1
+      f1,f2,f3=[],[],[]
       serve.each do |x|
         f1 << %{              <option value="SiSU_#{x}">#{x}</option>\n} unless x =~/apache|sisu\/image/ #check
       end
       f2 <<  %{          selected_db=case cgi['db']\n}
       serve.each do |x|
-        f2 << %{          when /SiSU_#{x}/:        '<option value="SiSU_#{x}">#{x}</option>'\n} unless x =~/apache|sisu\/image/ #check
+        f2 << %{          when /SiSU_#{x}/;        '<option value="SiSU_#{x}">#{x}</option>'\n} unless x =~/apache|sisu\/image/ #check
       end
       f2 << "          end\n"
       if FileTest.writable?('.') 
@@ -92,7 +91,7 @@ module  SiSU_CGI_pgsql
         tell=SiSU_Screen::Ansi.new(@opt.cmd,a) 
         tell.print_grey
         c=case @webserv
-        when /pwd/: ''
+        when /pwd/; ''
         else "sudo cp -vi #{Dir.pwd}/sisu_pgsql.cgi /usr/lib/cgi-bin 
                   sudo chmod -v 755 /usr/lib/cgi-bin/sisu_pgsql.cgi
                   (copy sisu_pgsql.cgi to your cgi directory) and set file permissions to 755"
@@ -165,7 +164,7 @@ module  SiSU_CGI_pgsql
       require 'fcgi'
       require 'dbi'
       @version='sisu_pgsql'
-      @url_base="#{SiSU_Env::Info_dir.new.webserv_url_base}/_sisu/image"
+      @url_base="#{SiSU_Env::Info_env.new.url.webserv_base}/_sisu/image"
       WOK_SQL
     end
     def header1
@@ -302,13 +301,14 @@ module  SiSU_CGI_pgsql
           end
         end
         def text_to_match(identifier='')
-          m=Hash.new
-          m[:string]=/#{identifier}\s*(.+?)/
-          m[:string]=/#{identifier}\s*(.+?)(?:;|\n|\r|$)/
-          m[:word]=/#{identifier}[\s(]*(\S+)/
+          m={ 
+            :string => /#{identifier}\s*(.+?)/,
+            :string => /#{identifier}\s*(.+?)(?:;|\n|\r|$)/,
+            :word => /#{identifier}[\s(]*(\S+)/
+          }
           search_string=if @search_field =~m[:word]
-            search_string=if @search_field =~m[:braces]: m[:braces].match(@search_field)[1]
-            elsif @search_field =~m[:string]:            m[:string].match(@search_field)[1]
+            search_string=if @search_field =~m[:braces]; m[:braces].match(@search_field)[1]
+            elsif @search_field =~m[:string];            m[:string].match(@search_field)[1]
             else
               str=m[:word].match(@search_field)[1]
               str.gsub!(/[()]/,'')
@@ -331,14 +331,12 @@ module  SiSU_CGI_pgsql
           @l,@t,@q=l,t,q
         end
         def string
-          search=Hash.new
-          search[:search]=Array.new
-          search[:flag]=false
+          search={ :search => [],:flag => false }
           if @t =~/\S+/ or @q =~/\S+/
-            if @t =~/\S+/:     unescaped_search=CGI.unescape(@t)
-            elsif @q =~/\S+/:  unescaped_search=CGI.unescape(@q)
+            if @t =~/\S+/;     unescaped_search=CGI.unescape(@t)
+            elsif @q =~/\S+/;  unescaped_search=CGI.unescape(@q)
             end
-            search_construct=Array.new
+            search_construct=[]
             unescaped_search.gsub!(/\s*(AND|OR)\s*/,"' \) \\1 #@l~\( '")
             unescaped_search.gsub!(/(.+)/,"#@l~\( '\\1' \)")
             search_construct << unescaped_search
@@ -355,8 +353,7 @@ module  SiSU_CGI_pgsql
         def initialize(conn,search_for,q)
           @conn=conn
           @text_search_flag=false
-          search=Hash.new
-          search[:text],search[:endnotes]=Array.new,Array.new
+          search={ :text => [], :endnotes => [] }
           st=Dbi_search_string.new('documents.clean',search_for.text1,q['s1']).string
           se=Dbi_search_string.new('endnotes.clean',search_for.text1,q['s1']).string
           @text_search_flag=st[:flag]
@@ -449,7 +446,7 @@ module  SiSU_CGI_pgsql
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          @search_text,@search_endnotes=Array.new,Array.new
+          @search_text,@search_endnotes=[],[]
                                                                                  #%
           search[:text].each{|x| @search_text << "#{x} AND " }
           search[:endnotes].each{|x| @search_endnotes << "#{x} AND " }
