@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: generates naive cgi search form for search of sisu database (pgsql sqlite)
 
@@ -53,43 +53,43 @@ module  SiSU_CGI_sqlite
   class SiSU_search_sqlite
     def initialize(opt,webserv)
       @opt,@webserv=opt,webserv
-      webrick_port=SiSU_Env::Info_dir.new.webrick_port
-      @port=case @opt.mod_s
-      when /--webserve?r?=webrick/
+      webrick_port=SiSU_Env::Info_env.new.webrick_port
+      @port=case @opt.mod.inspect
+      when /--webserve?r?[=-]webrick/
         @webrick_port=":#{webrick_port}"
         "        '#@webrick_port'\n"
       else
         @webrick_port=''
         "        ''\n"
       end
-      @url_base="#{SiSU_Env::Info_dir.new.webserv_url_base}/_sisu/image"
-      @env=SiSU_Env::Info_dir.new
+      @url_base="#{SiSU_Env::Info_env.new.url.webserv_base}/_sisu/image"
+      @env=SiSU_Env::Info_env.new
       @common=SiSU_CGI_sql::SiSU_CGI_common.new(@webserv,@opt.cmd,@port,@webrick_port,@url_base,@env)
     end
     def sqlite
-      serve=Array.new
-      Dir.foreach(@env.webserv_path) do |x| 
-        if x !~/^\./ and FileTest.directory?("#{@env.webserv_path}/#{x}") 
-          if FileTest.file?("#{@env.webserv_path}/#{x}/sisu_sqlite.db"): serve << x unless x =~/^_\S+/ 
+      serve=[]
+      Dir.foreach(@env.path.webserv) do |x| 
+        if x !~/^\./ and FileTest.directory?("#{@env.path.webserv}/#{x}") 
+          if FileTest.file?("#{@env.path.webserv}/#{x}/sisu_sqlite.db"); serve << x unless x =~/^_\S+/ 
           end
         end
       end
       serve.sort!
-      f1,f2,f3=Array.new,Array.new,Array.new
+      f1,f2,f3=[],[],[]
       #f1
       serve.each do |x|
         f1 << %{              <option value="SiSU_#{x}">#{x}</option>\n}
       end
       f2 <<  %{          selected_db=case cgi['db']\n}
       serve.each do |x|
-        f2 << %{           when /SiSU_#{x}/: '<option value="SiSU_#{x}">#{x}</option>'\n}
+        f2 << %{           when /SiSU_#{x}/; '<option value="SiSU_#{x}">#{x}</option>'\n}
       end
       f2 << "          end\n"
       #f3
       f3 << %{          db_name='sisu_sqlite.db'\n}
       f3 << %{          db_sqlite=case cgi['db']\n}
       serve.each do |x|
-        f3 << %{          when /SiSU_#{x}/:                      "#{@env.webserv_path}/#{x}/sisu_sqlite.db"\n}
+        f3 << %{          when /SiSU_#{x}/;                      "#{@env.path.webserv}/#{x}/sisu_sqlite.db"\n}
       end
       f3 << "          end\n"
       if FileTest.writable?('.') 
@@ -101,7 +101,7 @@ module  SiSU_CGI_sqlite
         tell=SiSU_Screen::Ansi.new(@opt.cmd,a) 
         tell.print_grey
         c=case @webserv
-        when /pwd/: ''
+        when /pwd/; ''
         else "sudo cp -vi #{Dir.pwd}/sisu_sqlite.cgi /usr/lib/cgi-bin 
                   sudo chmod -v 755 /usr/lib/cgi-bin/sisu_sqlite.cgi
                   (copy sisu_sqlite.cgi to your cgi directory) and set file permissions to 755"
@@ -174,7 +174,7 @@ module  SiSU_CGI_sqlite
       require 'fcgi'
       require 'dbi'
       @version='sisu_sqlite'
-      @url_base="#{SiSU_Env::Info_dir.new.webserv_url_base}/_sisu/image"
+      @url_base="#{SiSU_Env::Info_env.new.url.webserv_base}/_sisu/image"
       WOK_SQL
     end
     def header1
@@ -310,13 +310,14 @@ module  SiSU_CGI_sqlite
           end
         end
         def text_to_match(identifier='')
-          m=Hash.new
-          m[:string]=/#{identifier}\s*(.+?)/
-          m[:string]=/#{identifier}\s*(.+?)(?:;|\n|\r|$)/
-          m[:word]=/#{identifier}[\s(]*(\S+)/
+          m={
+            :string => /#{identifier}\s*(.+?)/,
+            :string => /#{identifier}\s*(.+?)(?:;|\n|\r|$)/,
+            :word => /#{identifier}[\s(]*(\S+)/
+          }
           search_string=if @search_field =~m[:word]
-            search_string=if @search_field =~m[:braces]: m[:braces].match(@search_field)[1]
-            elsif @search_field =~m[:string]:            m[:string].match(@search_field)[1]
+            search_string=if @search_field =~m[:braces]; m[:braces].match(@search_field)[1]
+            elsif @search_field =~m[:string];            m[:string].match(@search_field)[1]
             else
               str=m[:word].match(@search_field)[1]
               str.gsub!(/[()]/,'')
@@ -339,14 +340,13 @@ module  SiSU_CGI_sqlite
           @l,@t,@q=l,t,q
         end
         def string
-          search=Hash.new
-          search[:search]=Array.new
+          search={ :search => [] }
           search[:flag]=false
           if @t =~/\S+/ or @q =~/\S+/
-            if @t =~/\S+/:     unescaped_search=CGI.unescape(@t)
-            elsif @q =~/\S+/:  unescaped_search=CGI.unescape(@q)
+            if @t =~/\S+/;     unescaped_search=CGI.unescape(@t)
+            elsif @q =~/\S+/;  unescaped_search=CGI.unescape(@q)
             end
-            search_construct=Array.new
+            search_construct=[]
             unescaped_search.gsub!(/\s*(AND|OR)\s*/,"%' \) \\1 #@l LIKE \( '%")
             unescaped_search.gsub!(/(.+)/,"#@l LIKE \( '%\\1%' \)")
             search_construct << unescaped_search
@@ -363,8 +363,7 @@ module  SiSU_CGI_sqlite
         def initialize(conn,search_for,q)
           @conn=conn
           @text_search_flag=false
-          search=Hash.new
-          search[:text],search[:endnotes]=Array.new,Array.new
+          search={ :text => [],:endnotes => [] }
           st=Dbi_search_string.new('documents.clean',search_for.text1,q['s1']).string
           se=Dbi_search_string.new('endnotes.clean',search_for.text1,q['s1']).string
           @text_search_flag=st[:flag]
@@ -457,7 +456,7 @@ module  SiSU_CGI_sqlite
             search[:text]                    << st[:search]
             search[:endnotes]                << st[:search]
           end
-          @search_text,@search_endnotes=Array.new,Array.new
+          @search_text,@search_endnotes=[],[]
                                                                                  #%
           search[:text].each{|x| @search_text << "#{x} AND " }
           search[:endnotes].each{|x| @search_endnotes << "#{x} AND " }
