@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: modules related to locales, character encoding for different output generators [requires kirbybase]
 
@@ -58,15 +58,15 @@ module SiSU_character_encode
   class Create <Characters
     def initialize
       #NOTE places character_encoding.tbl in correct subdirectory ./_sisu_processing/encoding
-      #@env=SiSU_Env::Info_dir.new
-      #env=@env.encoding
+      #@env=SiSU_Env::Info_env.new
+      #env=@env.path.encoding
       #@db=KirbyBase.new(:local,nil,nil,env)
       @db=KirbyBase.new                                         #default database location, pwd
       @ce_tbl=@db.create_table(:character_encoding, :glyph,:String, :dec,:Integer, :hex,:String, :rb,:String, :html,:String, :html_name,:String, :tex,:String, :tex_licr,:String, :tex_alt,:String, :name,:String)
     end
     def db
       x=Character_encoding.new.table
-      #x.each {|y| p y[2]}
+      #x.each {|y| puts y[2].inspect}
       x.each do |c|
         #puts "#{c[0]}, #{c[1]}, #{c[2]}, #{c[3]}, #{c[4]}, #{c[5]}, #{c[6]}, #{c[7]}, #{c[8]}, #{c[9]}"
         @ce_tbl.insert(c[0], c[1], c[2], c[3], c[4], c[5], c[6], c[7], c[8], c[9])
@@ -76,27 +76,24 @@ module SiSU_character_encode
   class Query
     def initialize(find='',show='')
       #NOTE character_encoding.tbl not read from subdirectory ./_sisu_processing/encoding
-      #@env=SiSU_Env::Info_dir.new
-      #env=@env.encoding
-      #@db=KirbyBase.new(:local,nil,nil,env)
       @db=KirbyBase.new                                         #default database location, pwd
       @ce_tbl=@db.get_table(:character_encoding)
       @find=find
     end
     def selected(selected,show)
-      @y=Array.new
+      @y=[]
       selected.each do |x| 
         @y<<case show
-        when 'glyph':     x.glyph
-        when 'dec':       x.dec
-        when 'hex':       x.hex
-        when 'rb':        x.rb
-        when 'html':      x.html
-        when 'html_name': x.html_name
-        when 'tex':       x.tex
-        when 'ot1':       x.ot1
-        when 'ts1':       x.ts1
-        when 'name':      x.name
+        when 'glyph';     x.glyph
+        when 'dec';       x.dec
+        when 'hex';       x.hex
+        when 'rb';        x.rb
+        when 'html';      x.html
+        when 'html_name'; x.html_name
+        when 'tex';       x.tex
+        when 'ot1';       x.ot1
+        when 'ts1';       x.ts1
+        when 'name';      x.name
         else              x.hex
         end
       end
@@ -135,7 +132,7 @@ module SiSU_character_encode
   end
   class Character_encoding
     def table
-      x=Array.new
+      x=[]
 #:glyph, :dec,:hex,  :rb,            :xml ,   :html_name,  :tex,    :tex_licr,         :tex_alt,          :name
       x=[                                                                                        
   ['',     9, '',    '',             '&#009;', nil,         '',     '',                '',                'Horizontal tab'  ],
