@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: color defaults
 
@@ -201,7 +201,6 @@ module SiSU_Hex_triplets
     end
     def body
       %{\n<body bgcolor="#ffffff" text="#000000" link="#003090" lang="en" xml:lang="en">\n}
-      #%{\n<body bgcolor="#ffffff" text="#000000" link="#003090" vlink"#0044cc" lang="en">\n}
     end
     def font
       "#{self.black}"
