@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: css stylesheets
 
@@ -254,6 +254,15 @@ WOK
     margin-right: 0px;
     text-align: left;
   }
+  p.tiny_left {
+    font-size: 10px;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    color: #777777;
+    margin-left: 0px;
+    margin-right: 0px;
+    text-align: left;
+  }
   p.tiny_right {
     font-size: 10px;
     margin-top: 0px;
@@ -1201,7 +1210,7 @@ WOK
       margin-top: 2px;
       margin-bottom: 0px;
     }
-    text.poem, text.group, text.code {
+    text.verse, text.group, text.code {
       text-align: left;
     }
     text.h1 {
@@ -1384,7 +1393,7 @@ WOK
       margin-top: 2px;
       margin-bottom: 0px;
     }
-    text.poem, text.group, text.code {
+    text.verse, text.group, text.code {
       text-align: left;
     }
     text.norm {
@@ -1586,7 +1595,7 @@ WOK
       margin-top: 2px;
       margin-bottom: 0px;
     }
-    para.poem, para.group, para.code {
+    para.verse, para.group, para.code {
       text-align: left;
     }
     para.norm {
