@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: Default values (reset by skins)
 
@@ -69,7 +69,7 @@ module SiSU_Viz
       '&nbsp;'
     end
   end
-  class Php #
+  class Php
     def persist
     end
   end
@@ -120,6 +120,8 @@ module SiSU_Viz
     end
     def pdf
     end
+    def odf
+    end
     def concordance
     end
     def instruments
@@ -137,10 +139,10 @@ module SiSU_Viz
     def old
     end
   end
-  class Path < SiSU_Env::Info_dir
+  class Path < SiSU_Env::Info_env
     def stylesheet_home
-      dir=SiSU_Env::Info_dir.new
-      %{  <link rel="stylesheet" href="./#{dir.style}/index.css" type="text/css" />}
+      dir=SiSU_Env::Info_env.new
+      %{  <link rel="stylesheet" href="./#{dir.path.style}/index.css" type="text/css" />}
     end
   end
   class Url < Path
@@ -201,7 +203,6 @@ module SiSU_Viz
     end
     def body
       %{<body bgcolor="#ffffff" text="#000000" link="#003090" lang="en" xml:lang="en">}
-      #%{\n<body bgcolor="#ffffff" text="#000000" link="#003090" vlink"#0044cc" lang="en">\n}
     end
   end
   class Icon
@@ -223,6 +224,9 @@ module SiSU_Viz
     def wmp
       'b_wmp.png'
     end
+    def odf
+      'b_odf.png'
+    end
     def pdf
       'b_pdf.png'
     end
@@ -309,18 +313,12 @@ module SiSU_Viz
       'blueband.png'
     end
     def next
-      #'next.png'
-      #'arrow_next_blue.png'
       'arrow_next_red.png'
     end
     def previous
-      #'previous.png'
-      #'arrow_prev_blue.png'
       'arrow_prev_red.png'
     end
     def up
-      #'toctoc.png'
-      #'arrow_up_blue.png'
       'arrow_up_red.png'
     end
   end
@@ -421,18 +419,18 @@ module SiSU_Viz
     def make_italic
       if defined? italics_list and italics_list
         #make=italics_list.split(/;\s+/).join('|').strip
-        make=Hash.new
+        make={}
         if italics_list
           r=italics_list.dup
           x=case r
-          when /\/i$/: 'i'
+          when /\/i$/; 'i'
           else         ''
           end
           r.gsub!(/^\/(.+?)\/i?/,'\1')
           r.gsub!(/\(/,'(?:') # avoid need to escape use of brackets within regex provided
           m='\b(' + r + ')\b'
           make[:str]
-          make[:regx]=if x =~/i/: /#{m}/i
+          make[:regx]=if x =~/i/; /#{m}/i
           else                    /#{m}/
           end
         else nil
@@ -441,19 +439,19 @@ module SiSU_Viz
     end
     def make_bold
       if defined? bold_list and not bold_list.empty?
-        make=Hash.new
+        make={}
         if bold_list
           #make=bold_list.split(/;\s+/).join('|').strip
           r=bold_list.dup
           x=case r
-          when /\/i$/: 'i'
+          when /\/i$/; 'i'
           else         ''
           end
           r.gsub!(/^\/(.+?)\/i?/,'\1')
           r.gsub!(/\(/,'(?:') # avoid need to escape use of brackets within regex provided
           m='\b(' + r + ')\b'
           make[:str]
-          make[:regx]=if x =~/i/: /#{m}/i
+          make[:regx]=if x =~/i/; /#{m}/i
           else                    /#{m}/
           end
         else nil
@@ -624,18 +622,18 @@ module SiSU_Viz
       @color=Color.new
     end
     def num
-      %{</p> </td><td width="4%" align="right" valign="top">}
+      '</p> </td><td width="4%" align="right" valign="top">'
     end
     def numless
-      %{</td><td width="4%" align="right" valign="top">}
+      '</td><td width="4%" align="right" valign="top">'
     end
     def num_css
-      %{</td>
-<td width="2%" align="right" valign="top">  }
+      '</td>
+<td width="2%" align="right" valign="top">  '
     end
     def num_header
-      %{</td>
-<td width="4%" align="right" valign="top">}
+      '</td>
+<td width="4%" align="right" valign="top">'
     end
     def txt_num_0
       %{<td width=#{@indent.level_0} align="right">
@@ -724,8 +722,8 @@ module SiSU_Viz
 <td valign="top" align="justify">}
     end
     def css
-      %{<table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
-<tr><td valign="top" align="justify"> }
+      '<table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
+<tr><td valign="top" align="justify"> '
     end
     def table_paper_nomargin
       %{<table summary="" width=#{@table.width_3} border="0" cellpadding=#{@table.cellpad_shadow} bgcolor=#{@color.nav_penumbra} align="center">
@@ -748,7 +746,7 @@ module SiSU_Viz
       %{<table summary="" width="100%" border="0" cellpadding=#{@table.cellpad_small_paper_margins} bgcolor=#{@color.paper} align="justify">\n<tr><td>\n<font color="#000000"><p />\n}
     end
   end
-  class TeX #unit: mm
+  class TeX
     def initialize(papersize='')
       @papersize=papersize
     end
@@ -889,11 +887,11 @@ module SiSU_Viz
     end
     def dimensions
       d=case @papersize
-      when /a4/:     a4
-      when /letter/: letter
-      when /legal/:  legal
-      when /b5/:     b5
-      when /a5/:     a5
+      when /a4/;     a4
+      when /letter/; letter
+      when /legal/;  legal
+      when /b5/;     b5
+      when /a5/;     a5
       else           a4
       end
     end
@@ -913,9 +911,9 @@ module SiSU_Viz
   </a>}
     end
     def hp
-      dir=SiSU_Env::Info_dir.new #(@fns)
+      dir=SiSU_Env::Info_env.new #(@fns)
       %{  <a href="#{@url.site}">
-    <img border="0" width="160" height="60" src="#{dir.url_images_local}/#{@icon.home_banner}" alt="#{@txt.home}" />
+    <img border="0" width="160" height="60" src="#{dir.url.images_local}/#{@icon.home_banner}" alt="#{@txt.home}" />
   </a>}
     end
     def hp_nav
@@ -933,6 +931,9 @@ module SiSU_Viz
     def toc
       %{<img border="0" height="18" width="15" src="#{@url.path_image}/#{@icon.toc}" alt="TOC linked" />}
     end
+    def odf
+      %{<img border="0" height="18" width="18" src="#{@url.path_image}/#{@icon.odf}" alt="ODF/ODT" />}
+    end
     def pdf
       %{<img border="0" height="18" width="15" src="#{@url.path_image}/#{@icon.pdf}" alt="PDF" />}
     end
@@ -979,12 +980,12 @@ module SiSU_Viz
       %{<img border="0" height="15" width="15" src="#{@url.path_image}/#{@icon.external_toc}" alt="lateral hop" />}
     end
     def home
-      dir=SiSU_Env::Info_dir.new #(@fns)
-      %{<img border="0" src="#{dir.url_images_local}/#{@icon.home_button}" alt="#{@txt.home} --&gt;" />}
+      dir=SiSU_Env::Info_env.new #(@fns)
+      %{<img border="0" src="#{dir.url.images_local}/#{@icon.home_button}" alt="#{@txt.home} --&gt;" />}
     end
     def site
-      dir=SiSU_Env::Info_dir.new #(@fns)
-      %{<img src="#{dir.url_images_local}/#{@icon.home_banner}" alt="#{@url.txt}" border="0" />}
+      dir=SiSU_Env::Info_env.new #(@fns)
+      %{<img src="#{dir.url.images_local}/#{@icon.home_banner}" alt="#{@url.txt}" border="0" />}
     end
     def book
       %{<img border="2" height="15" width="15" src="#{@url.path_image}/#{@icon.book}" alt="Cameron May Books" />}
@@ -1019,14 +1020,19 @@ module SiSU_Viz
   </font> }
     end
     def previous
-      %{  <font face="" size="2">
+      '  <font face="" size="2">
     &nbsp;&nbsp;<b>&lt;&lt;</b>&nbsp;Previous&nbsp;&nbsp;
   </font> 
-  Full&nbsp;Text&nbsp;}
+  Full&nbsp;Text&nbsp;'
     end
     def next
       %{  <font face="#{@font.fonts}" size="2">
     &nbsp;&nbsp;Next&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<b>&gt;&gt;</b>&nbsp;&nbsp;
+  </font> }
+    end
+    def odf
+      %{  <font face="#{@font.fonts}" size="2">
+    #{@png.odf}&nbsp;&nbsp;odt&nbsp;
   </font> }
     end
     def pdfs
@@ -1071,6 +1077,9 @@ module SiSU_Viz
     def nxt
       self.next
     end
+    def pdf
+      %{<img border="0" height="18" width="15" src="#{@url.path_image}/#{@icon.pdf}" alt="PDF" />}
+    end
     def pdf_portrait
       %{<img border="0" width="15" height="18" src="#{@url.path_image}/#{@icon.pdf}" alt="pdf portrait" />}
     end
@@ -1078,13 +1087,13 @@ module SiSU_Viz
       %{<img border="0" width="18" height="15" src="#{@url.path_image}/#{@icon.pdf}" alt="pdf landscape" />}
     end
     def dot_toc
-      %{<img border="0" width="100%" height="20" src="#{@url.path_image}/#{@icon.dot}" alt="~/." />}
+      %{<img border="0" width="100%" height="20" src="#{@url.path_image}/#{@icon.dot}" alt="&#094;" />}
     end
     def dot_previous
-      %{<img border="0" width="100%" height="20" src="#{@url.path_image}/#{@icon.dot}" alt="&lt;&lt; Pre" />}
+      %{<img border="0" width="100%" height="20" src="#{@url.path_image}/#{@icon.dot}" alt="&lt;" />}
     end
     def dot_next
-      %{<img border="0" width="100%" height="20" src="#{@url.path_image}/#{@icon.dot}" alt="Nxt &gt;&gt;" />}
+      %{<img border="0" width="100%" height="20" src="#{@url.path_image}/#{@icon.dot}" alt="&gt;" />}
     end
     def dot_pre
       dot_previous
@@ -1105,13 +1114,12 @@ module SiSU_Viz
       @js=SiSU_Viz::Javascript.new
     end
     def blueband
-      #%{<center><img border="0" height="2" width="240" src="#{@url.path_image}/#{@icon.bluedot}"></center>}
       %{<img border="0" height="2" width="240" src="#{@url.path_image}/#{@icon.bluedot}" />}
     end
     def open_blue
-      %{  <center>
+      '  <center>
 <table summary="blueband" border="0" cellpadding="0" bgcolor="#ffffff" align="center" width="240">
-<tr><td align="center">}
+<tr><td align="center">'
     end
     def close_blue
       %{#{@table.close}
@@ -1155,6 +1163,11 @@ module SiSU_Viz
       #{@png.doc} LM 20**
     </a>
   <br />}
+    end
+    def home_button_only
+  %{<a href="#{@url.site}/" #{@js.home}>
+    #{@png.home}
+  </a>}
     end
     def home_button #yellow_dark now white
       %{<table summary="home button" width="100%" border="0" cellpadding="3" bgcolor= "#ffffff" align="center">
@@ -1238,7 +1251,7 @@ module SiSU_Viz
 </td>
 <td align="center" valign="middle" bgcolor=#{@color.beige}>
   <font face="arial" size="2">
-    <a href="http://www.jus.uio.no/lm/information.technology/information.technology" target="_top" #{@js.home}>
+    <a href="http://www.jus.uio.no/lm/information.technology/information.technology.html" target="_top" #{@js.home}>
       Information
     <br />
       Technology
@@ -1276,30 +1289,30 @@ module SiSU_Viz
 #{@table.close}\n} #browser bug? cannot have align left for table or causes text to move behind table 
     end
     def book_cover_band
-      %{<table summary="book cover band" width="100%" border="0" cellpadding="8" bgcolor="#ffffff" align="center">
-<tr><td align="center">}
+      '<table summary="book cover band" width="100%" border="0" cellpadding="8" bgcolor="#ffffff" align="center">
+<tr><td align="center">'
     end
     def instrument_cover_band
-      %{<table summary="generic instrument cover band" width="100%" border="0" cellpadding="8" bgcolor="#ffffff" align="center">
-<tr><td align="center">}
+      '<table summary="generic instrument cover band" width="100%" border="0" cellpadding="8" bgcolor="#ffffff" align="center">
+<tr><td align="center">'
     end
     def instrument_cover_band_scr
-      %{<table summary="scroll instrument cover band" width="100%" border="0" cellpadding="8" bgcolor="#ffffff" align="center">
-<tr><td align="center">}
+      '<table summary="scroll instrument cover band" width="100%" border="0" cellpadding="8" bgcolor="#ffffff" align="center">
+<tr><td align="center">'
     end
     def instrument_cover_band_seg
-      %{<table summary="segment instrument cover band, title, author, location" width="100%" border="0" cellpadding="8" bgcolor="#ffffff" align="center">
-<tr><td align="center">}
+      '<table summary="segment instrument cover band, title, author, location" width="100%" border="0" cellpadding="8" bgcolor="#ffffff" align="center">
+<tr><td align="center">'
     end
     def reserve
-      %{  <p />
+      '  <p />
   <center>
   <br />
   <font color="white">
     <i>E-presentation</i> <sup>&copy;</sup> Ralph Amissah<br /><i>- & for his personal use only!</i>
   <br />
     <i>W3 since October 3 1993</i>
-  </center>}
+  </center>'
     end
     def control
       %{  <center>
@@ -1343,7 +1356,6 @@ module SiSU_Viz
       @date=SiSU_Env::Info_date.new
     end
     def browsers
-#tidy 7 warnings here
 <<WOK
 <tr align="center"><td align="center">
 <table summary="browser suggestions" bgcolor="#ffffff" cellpadding="4" border="0">
@@ -1359,7 +1371,6 @@ module SiSU_Viz
   <p>
   <font color="#666666" size="1">
     <a href="http://www.gnome.org/projects/epiphany/" target="external">
-      <img border="0" width="25" height="25" src="../_sisu/image/gnome.png" alt="Epiphany" />
         &nbsp;Epiphany
       </a>
       <sup>&reg;</sup>&nbsp;|
@@ -1370,7 +1381,6 @@ module SiSU_Viz
   <p>
   <font color="#666666" size="1">
     <a href="http://galeon.sourceforge.net/" target="external">
-    <img border="0" width="24" height="24" src="../_sisu/image/galeon.png" alt="Galeon" />
       &nbsp;Galeon
     </a>
     <sup>&reg;</sup>&nbsp;|
@@ -1381,7 +1391,6 @@ module SiSU_Viz
   <p>
   <font color="#666666" size="1">
     <a href="http://www.microsoft.com/windows/ie/default.asp" target="external">
-    <img border="0" width="29" height="25" src="../_sisu/image/internet.explorer.png" alt="MS I-Explorer" />
       I-Explorer
     </a>
     <sup>&reg;</sup>&nbsp;|
@@ -1399,18 +1408,15 @@ module SiSU_Viz
   <p>
   <font color="#666666" size="1">
     <a href="http://www.konqueror.org/" target="external">
-    <img border="0" width="29" height="25" src="../_sisu/image/konqueror.png" alt="Konqueror" />
     Konqueror</a>
     <sup>&reg;</sup>&nbsp;|</font></p></td>
 <td>
   <p>
   <font color="#666666" size="1">
     <a href="http://www.mozilla.org/" target="external">
-    <img border="0" width="30" height="24" src="../_sisu/image/mozilla.png" alt="Mozilla" />
       Mozilla
     </a>
     <a href="http://www.mozilla.org/products/firefox/" target="external">
-      <img border="0" width="25" height="25" src="../_sisu/image/firefox.png" alt="Firefox" />
       <b>Firefox</b>
     </a>
     <sup>&reg;</sup>&nbsp;|
@@ -1421,7 +1427,6 @@ module SiSU_Viz
   <p>
   <font color="#666666" size="1">
     <a href="http://home.netscape.com/comprod/mirror/client_download.html" target="external">
-      <img border="0" width="29" height="25" src="../_sisu/image/netscape.png" alt="Netscape" />
       Netscape
     </a>
     <sup>&reg;</sup>&nbsp;|
@@ -1432,7 +1437,6 @@ module SiSU_Viz
   <p>
   <font color="#666666" size="1">
     <a href="http://www.opera.com/" target="external">
-      <img border="0" width="29" height="25" src="../_sisu/image/opera.png" alt="Opera" />
       Opera
     </a>
     <sup>&reg;</sup>&nbsp;|
@@ -1443,7 +1447,6 @@ module SiSU_Viz
   <p>
   <font color="#666666" size="1">
     <a href="http://www.apple.com/safari/" target="external">
-      <img border="0" width="24" height="25" src="../_sisu/image/safari.png" alt="Safari" />
       Safari
     </a>
     <sup>&reg;</sup>
@@ -1506,7 +1509,6 @@ module SiSU_Viz
   <p>
   <font color="#666666" size="1">
     <a href="http://www.gnome.org/projects/epiphany/" target="external">
-      <img border="0" width="25" height="25" src="../_sisu/image/gnome.png" alt="Epiphany" />
       &nbsp;Epiphany
     </a>
     <sup>&reg;</sup>&nbsp;|
@@ -1517,7 +1519,6 @@ module SiSU_Viz
   <p>
   <font color="#666666" size="1">
     <a href="http://galeon.sourceforge.net/" target="external">
-    <img border="0" width="24" height="24" src="../_sisu/image/galeon.png" alt="Galeon" />
       &nbsp;Galeon
     </a>&nbsp;|
   </font>
@@ -1557,7 +1558,6 @@ WOK
   <p class="center">
   <font color="#666666" size="1">
     <a href="http://www.adobe.com/products/acrobat/readstep2.html" target="external">
-      <img border="0" height="18" width="15" src="../_sisu/image/b_pdf.png" alt="Adobe Acrobat Reader" />
       Acrobat Reader
     </a>
     <sup>&reg;</sup>
@@ -1569,7 +1569,6 @@ WOK
   <p class="center">
   <font color="#666666" size="1">
     <a href="http://www.gnome.org/projects/evince/" target="external">
-      <img border="0" width="25" height="25" src="../_sisu/image/gnome.png" alt="Evince" />
       <b>Evince</b>
     </a>
     <sup>&reg;</sup>
@@ -1595,7 +1594,6 @@ WOK
   <p class="center">
   <font color="#666666" size="1">
     <a href="http://www.foolabs.com/xpdf/" target="external">
-    <img border="0" width="16" height="16" src="../_sisu/image/xpdf.png" alt="Xpdf" />
       &nbsp;Xpdf
     </a>
     <sup>&reg;</sup>
@@ -1649,7 +1647,7 @@ WOK
     generated by
   <br />
     <a href="#{@url.sisu}" #{@js.sisu}>
-      <img border="0" src="../_sisu/image/sisu.png" alt="SiSU on Debian/Gnu/Linux or a FreeBSD &amp; Ruby - better ways, well actually, Way Better!" width="120" height="39" />
+      <img border="0" src="../_sisu/image/sisu.png" alt="SiSU" width="120" height="39" />
     </a>
     <br />
     <a href="#{@url.sisu}" #{@js.sisu}>
@@ -1690,8 +1688,9 @@ WOK
     All Rights Reserved.
   <br />
     SiSU is the result of several years of research and development in electronic
-    publishing, commenced in 1993 and under active development since 1997. There
-    is always more to be done. <b>SiSU is released under 
+    publishing, commenced in 1993 and under active development since 1997.
+  <br />
+    <b>SiSU is released under 
     <a href="http://www.gnu.org/copyleft/gpl.html">
       GPL 2
     </a> 
@@ -1699,6 +1698,7 @@ WOK
     <a href="http://www.gnu.org/copyleft/gpl.html">
       http://www.gnu.org/copyleft/gpl.html
     </a>
+  <br />
     (SiSU's first public release on January 4<sup>th</sup> 2005)
   <br />
   </font>
@@ -1739,12 +1739,6 @@ WOK
     software infrastructure,
   <br />
     &amp; with the usual GPL (or OSS) suspects.
-  <br />
-    Linux 
-    (<a href="http://www.debian.org/">Debian</a>)
-    &amp; Unix, 
-    (<a href="http://www.freebsd.org/">FreeBSD</a>/ 
-    <a href="http://www.dragonflybsd.org/main/">Dragonfly</a>)
   <br />
     Better - "performance, reliability, scalability, security
   <br />
@@ -1755,11 +1749,9 @@ WOK
   <br />
     Get With the Future
   <br />
-    &lt;&lt;
     <a href="http://www.jus.uio.no/sisu/">
       Way Better!
     </a>
-    &gt;&gt;
   </font>
   </p>
 #{@table.close}
@@ -1866,7 +1858,7 @@ WOK
     def initialize
       @font=Font.new
       @v=SiSU_Env::Info_version.new.get_version
-      @dir=SiSU_Env::Info_dir.new
+      @dir=SiSU_Env::Info_env.new
     end
     def sisu
 <<WOK
@@ -1882,7 +1874,6 @@ WOK
 WOK
     end
     def index
-      #meta_sisu_version=Txt.new.generator
       <<WOK
 <!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
 <html>
@@ -1904,7 +1895,7 @@ for search</title>
 <meta name="dc.rights" content="Copyright Ralph Amissah" />
 <meta name="generator" content="#{@v[:project]} #{@v[:version]} of #{@v[:date_stamp]} (#{@v[:date]}) (n*x and Ruby!)" />
 <link rel="generator" href="http://www.jus.uio.no/sisu/SiSU" />
-<link rel="stylesheet" href="./#{@dir.style}/html.css" type="text/css" />      
+<link rel="stylesheet" href="./#{@dir.path.style}/html.css" type="text/css" />      
 <link rel="shortcut icon" href="./_sisu/image/rb7.ico" />
 </head>
 <body>
@@ -1937,43 +1928,43 @@ outputs include: plaintext, html, xhtml, XML, ODF (OpenDocument), LaTeX, pdf, SQ
   </a>
 </p>
 <p>
-  <a href="http://www.jus.uio.no/sisu/sisu_description/1#summary" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/sisu_description/1.html#summary" target="_top" >
     What does SiSU do? Summary
   </a>
-  <a href="http://www.jus.uio.no/sisu/SiSU/1#summary" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/SiSU/1.html#summary" target="_top" >
     <sup>[*]</sup>
   </a>
 </p>
 <p>
-  <a href="http://www.jus.uio.no/sisu/sisu_examples/1#books" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/sisu_examples/1.html#books" target="_top" >
     Book Samples
   </a>
-  <a href="http://www.jus.uio.no/sisu/SiSU/2#books" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/SiSU/2.html#books" target="_top" >
     <sup>[*]</sup>
   </a>
 </p>
 <p>
-  <a href="http://www.jus.uio.no/sisu/sisu_examples/1#markup" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/sisu_examples/1.html#markup" target="_top" >
     Markup Examples
   </a>
-  <a href="http://www.jus.uio.no/sisu/SiSU/2#markup" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/SiSU/2.html#markup" target="_top" >
     <sup>[*]</sup>
   </a>
 </p>
 <p>
-  <a href="http://www.jus.uio.no/sisu/sisu_description/1#ocn" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/sisu_description/1.html#ocn" target="_top" >
     Object Citation Numbering - <i>ocn</i>
   </a>
-  <a href="http://www.jus.uio.no/sisu/SiSU/1#ocn" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/SiSU/1.html#ocn" target="_top" >
     <sup>[*]</sup>
   </a>
 </p>
 <p class="tiny">(a text positioning system)</p>
 <p>
-  <a href="http://www.jus.uio.no/sisu/sisu_description/1#search" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/sisu_description/1.html#search" target="_top" >
     Search - "<i>Atomic</i>"
   </a>
-  <a href="http://www.jus.uio.no/sisu/SiSU/1#search" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/SiSU/1.html#search" target="_top" >
     <sup>[*]</sup>
   </a>
 </p>
@@ -1984,26 +1975,26 @@ outputs include: plaintext, html, xhtml, XML, ODF (OpenDocument), LaTeX, pdf, SQ
   </a>
 </p>
 <p>
-  <a href="http://www.jus.uio.no/sisu/sisu_license/license" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/sisu_license/license.html" target="_top" >
     License
   </a>
-  <a href="http://www.jus.uio.no/sisu/SiSU/license" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/SiSU/license.html" target="_top" >
     <sup>[*]</sup>
   </a>
 </p>
 <p>
-  <a href="http://www.jus.uio.no/sisu/sisu_download/download" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/sisu_download/download.html" target="_top" >
     <b>Download</b>
   </a>
-  <a href="http://www.jus.uio.no/sisu/SiSU/download" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/SiSU/download.html" target="_top" >
     <sup>[*]</sup>
   </a>
 </p>
 <p>
-  <a href="http://www.jus.uio.no/sisu/sisu_changelog/changelog" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/sisu_changelog/changelog.html" target="_top" >
     Changelog
   </a>
-  <a href="http://www.jus.uio.no/sisu/SiSU/changelog" target="_top" >
+  <a href="http://www.jus.uio.no/sisu/SiSU/changelog.html" target="_top" >
     <sup>[*]</sup>
   </a>
 </p>
@@ -2100,7 +2091,7 @@ outputs include: plaintext, html, xhtml, XML, ODF (OpenDocument), LaTeX, pdf, SQ
 </p>
 <p><a href="http://www.jus.uio.no/sisu/SiSU" target="_top" ><b>SiSU</b> - Structured information, Serialized Units</a> for Electronic Documents, is a document creation/management framework with the following features:</p>
 <p><b>(i)</b> markup syntax: (a) simpler than html, (b) mnemonic, influenced by mail/messaging/wiki markup practices, (c) human readable, and easily writable,</p>
-<p><b>(ii)</b> (a) minimal markup requirement, (b) single file marked up for multiple outputs,</p>
+<p><b>(ii)</b> (a) minimal markup requirement, (b) single file prepared for multiple outputs,</p>
 <p><b>(iii)</b> (a) multiple outputs include amongst others: html; pdf via LaTeX; (structured) XML; ODF (OpenDocument); sql - currently PostgreSQL (and SQLite); ascii, (also texinfo), (b) takes advantage of the strengths implicit in these very different output types, (e.g. pdfs produced using typsetting of LaTeX, databases populated with documents at an individual object/paragraph level, with implications for search possibilities...)</p>
 <p><b>(iv)</b> provides a common object positioning and citation system for all outputs, which is human relevant and machine usable: <u><i>object citation numbering</i></u>, all objects (paragraphs, headings, verse, tables etc. and images) are numbered identically, for citation purposes, in all outputs (html, pdf, sql etc.),</p>
 <p><b>(v)</b> use of Dublin Core and other meta-tags to permit the addition of some semantic information on documents, and making easy integration of rdf/rss feeds etc.,</p>
