@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: xml (dom style) output processing
 
@@ -56,7 +56,7 @@ module SiSU_Docbook
   require SiSU_lib + '/sysenv'
   include SiSU_Env
   require SiSU_lib + '/metaverse'
-  require SiSU_lib + '/common_xml'
+  require SiSU_lib + '/shared_xml'
   require SiSU_lib + '/xml_format'
   include SiSU_XML_format
   include SiSU_XML_character
@@ -72,41 +72,40 @@ module SiSU_Docbook
     def read
       begin
         @md=SiSU_Param::Parameters.new(@opt).get
-        @dir=SiSU_Env::Info_dir.new(@opt.fns)
-        path=SiSU_Env::Info_dir.new(@opt.fns).tell_output_path
-        loc=SiSU_Env::Info_dir.new(@opt.fns).tell_output_location
-        tool=if @opt.cmd =~/[MV]/: "#{@dir.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:docbook]}\n\t#{@dir.xml_viewer} #{path}/#{@md.fnb}/#{@md.fn[:docbook]}"
-        elsif @opt.cmd =~/v/: "#{@dir.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:docbook]}"
+        @env=SiSU_Env::Info_env.new(@opt.fns)
+        path=@env.path.output_tell
+        loc=@env.url.output_tell
+        tool=if @opt.cmd =~/[MV]/; "#{@env.program.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:docbook]}\n\t#{@env.program.xml_viewer} #{path}/#{@md.fnb}/#{@md.fn[:docbook]}"
+        elsif @opt.cmd =~/v/; "#{@env.program.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:docbook]}"
         else ''
         end
         tell=SiSU_Screen::Ansi.new(@opt.cmd,'invert','XML DOM',tool)
         tell.colorize unless @opt.cmd =~/q/
-        tell=SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@dir.tell_output_path}/#{@md.fnb}/#{@md.fn[:docbook]}")
+        tell=SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.path.output_tell}/#{@md.fnb}/#{@md.fn[:docbook]}")
         tell.flow if @opt.cmd =~/[MV]/
         @metaverse_array=SiSU_Metaverse::Source.new(@opt).get # metaverse file drawn here
-        SiSU_Docbook::Source::Songsheet.new(@metaverse_array,@md,@dir).songsheet
-      rescue: SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
-      ensure
-        #file closed in songsheet
+        SiSU_Docbook::Source::Songsheet.new(@metaverse_array,@md,@env).songsheet
+      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      ensure #file closed in songsheet
       end
     end
     private
     class Songsheet
       def initialize(data,md='',dir='')
-        @data,@md,@dir=data,md,dir
+        @data,@md,@env=data,md,dir
       end
       def songsheet
         begin
           SiSU_Docbook::Source::Scroll.new(@data,@md).songsheet
-          SiSU_Docbook::Source::Tidy.new(@md,@dir).xml if @md.cmd =~/[VM]/i # test wellformedness, comment out when not in use
+          SiSU_Docbook::Source::Tidy.new(@md,@env).xml if @md.cmd =~/[vVM]/i # test wellformedness, comment out when not in use
           SiSU_Rexml::Rexml.new(@md,@md.fn[:docbook]).xml if @md.cmd =~/M/ # test rexml parsing, comment out when not in use #debug
-        rescue: SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
+        rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
         ensure
         end
       end
     end
     class Scroll
-      Heading,Heading_close,Contents=Array.new,Array.new,Array.new
+      Heading,Heading_close,Contents=[],[],[]
       Heading[0]='part'
       Heading[1]='part level="1"'
       Heading[2]='part level="2"'
@@ -118,39 +117,42 @@ module SiSU_Docbook
       Contents[1]='chapter'
       Contents[2]='sect1'
       Contents[3]='sect2'
-      @@xml=Hash.new
-      @@xml[:body],@@xml[:open],@@xml[:close],@@xml[:head],@@xml[:sc]=Array.new,Array.new,Array.new,Array.new,Array.new
+      @@xml={ :body=>[],:open=>[],:close=>[],:head=>[],:sc=[] }
       @@dp=nil
-      require SiSU_lib + '/common_text'
+      require SiSU_lib + '/shared_txt'
       include SiSU_text_utils
       def initialize(data='',md='')
         @data,@md=data,md
         @margin=SiSU_Viz::Margin.new
-        @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
-        @regx=/^(?:(?:<:p[bn]>\s*)?\d~(?:(\S+))?\s+)?(.+?)\s*<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>$/ # 
+        @@dp ||=SiSU_Env::Info_env.new.digest.pattern
+        @regx=/^(?:(?:<:p[bn]>\s*)?\d~(?:(\S+))?\s+)?(.+?)\s*<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>$/
         @tab="\t"
         @char_enc=SiSU_XML_character::Encode.new
         @sys=SiSU_Env::System_call.new
       end
       def songsheet
-        Scroll.new(@data,@md).pre
-        Scroll.new(@data,@md).markup
-        Scroll.new(@data,@md).post
-        Scroll.new(@data,@md).publish
+        pre
+        markup
+        post
+        publish
       end
     protected
       def xml_markup(para='')
         para.gsub!(/~\{(\d+)\s+(.+?)\s*<#{@@dp}>\}~/, 
-          "<footnote><para>\\1 \\2</para></footnote> ")
+          '<footnote><para>\1 \2</para></footnote> ')
       end
-      def xml_head(meta='',verse='')
-        verse.gsub!(/<br(?: \/)?>/, '')
-        verse.gsub!(/ & /, ' and ')
-        @@xml[:head] <<<<WOK
-#{@tab}<#{meta}>
-#{@tab*2}#{verse}
-#{@tab}</#{meta}>
+      def xml_head(meta)
+        txt=meta.text
+        txt.gsub!(/<br(?: \/)?>/,'')
+        txt.gsub!(/ & /,' and ')
+        @@xml[:head] <<=if meta.type == 'meta'
+          <<WOK
+#{@tab}<#{meta.el}>
+#{@tab*2}#{txt}
+#{@tab}</#{meta.el}>
 WOK
+        else ''
+        end
       end
       def xml_sc(md='')
         sc=if @md.sc_info
@@ -169,8 +171,7 @@ WOK
 WOK
         else ''
         end
-        @@xml[:sc]=sc   #<<<<WOK
-#WOK
+        @@xml[:sc]=sc
       end
       def xml_element(lv='',ocn='',para='',hname='',tag='',xml_element='')
         lv=lv.to_i
@@ -180,8 +181,7 @@ WOK
         n3=lv + 2
         v=lv - 3
         tag=''
-        tag="\n#{@tab*n3}<nametag>#{hname}</nametag>\n" if hname #!=nil
-# #{ocn}
+        tag="\n#{@tab*n3}<nametag>#{hname}</nametag>\n" if hname
         @@xml[:body] <<<<WOK
 #{@tab*n}#{xml_element}
 #{@tab*n1}<title>#{para[@regx, 2]}</title>
@@ -249,7 +249,7 @@ WOK
           cv=lv - 3
           if para =~/^4~\S+/
             m=/^4~(\S+)/.match(para)[1]
-            id=if m =~/^\d+$/: 'ch' + m
+            id=if m =~/^\d+$/; 'ch' + m
             else               'ch_' + m
             end
           elsif para =~/^5~\S+/
@@ -302,64 +302,61 @@ WOK
       def group_structure(para='',ocn='')
         para.gsub!(/<:group(?:-end)?>/,'')
         para.strip!
-        @@xml[:body] << %{#{@tab*7}<para class="group">#{@tab*1}\n} # #{ocn}
+        @@xml[:body] << %{#{@tab*7}<para class="group">#{@tab*1}\n}
         @@xml[:body] << %{#{@tab*8}#{para}#{@tab*1}\n}
         @@xml[:body] << %{#{@tab*7}</para>\n}
       end
       def poem_structure(para='',ocn='')
-        para.gsub!(/<:poem(?:-end)?>/,'')
+        para.gsub!(/<:verse(?:-end)?>/,'')
         para.strip!
-        @@xml[:body] << %{#{@tab*7}<para class="poem">#{@tab*1}\n} # #{ocn}
+        @@xml[:body] << %{#{@tab*7}<para class="verse">#{@tab*1}\n}
         @@xml[:body] << %{#{@tab*8}#{para}#{@tab*1}\n}
         @@xml[:body] << %{#{@tab*7}</para>\n}
       end
       def code_structure(para='',ocn='')
         para.gsub!(/<:code(?:-end)?>/,'')
         para.strip!
-        @@xml[:body] << %{#{@tab*7}<para class="code">#{@tab*1}\n} # #{ocn}
+        @@xml[:body] << %{#{@tab*7}<para class="code">#{@tab*1}\n}
         @@xml[:body] << %{#{@tab*8}#{para}#{@tab*1}\n}
         @@xml[:body] << %{#{@tab*7}</para>\n}
       end
       #def table_structure(table='',ocn='') #tables
       #  @@xml[:body] << %{#{@tab*1}#{table}\n#{@tab*1}\n} # unless lv  # main text, contents, body KEEP #{ocn}
-      #  @endnotes=Array.new
+      #  @endnotes=[]
       #end
       def tidywords(wordlist)
         wordlist.each do |x|
-          x.gsub!(/&/, '&amp;') unless x =~/&\S+;/
+          x.gsub!(/&/,'&amp;') unless x =~/&\S+;/
         end
       end
       def markup
         data=@data
-        dir=SiSU_Env::Info_dir.new(@md.fns)
+        dir=SiSU_Env::Info_env.new(@md.fns)
         xml_sc(@md)
         @rcdc=false
-        @level=Array.new
-        @cont=Array.new 
-        @copen=Array.new
-        @xml_contents_close=Array.new
+        @level,@cont,@copen,@xml_contents_close=[],[],[],[]
         (0..6).each { |x| @cont[x]=@level[x]=false } 
         (4..6).each { |x| @xml_contents_close[x]='' } 
         data.each do |para|
           wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
           para=tidywords(wordlist).join(' ').strip
-          para.gsub!(/<[-~]#>/, '')
-          para.gsub!(/<0;\w\d+;[um]\d+><#{@@dp}:#{@@dp}>/, '')
-          para.gsub!(/<:pb>\s*/, '')
-          para.gsub!(/\{(\S+?\.(?:png|jpg)) .+?\}(?:(?:https?|ftp):\/\/\S+|image)/, 
-            %{<imagedata fileref="#{dir.url_images_local}\/\\1"/>})
-          #para.gsub!(/\{(\S+?\.png) \d+x\d+ \".+?\" \}(?:http:\/\/\S+|image)/, "<image>\\1</image>")
-          para.gsub!(/&nbsp;/, ' ') #clean
+          para.gsub!(/<[-~]#>/,'')
+          para.gsub!(/<0;\w\d+;[um]\d+><#{@@dp}:#{@@dp}>/,'')
+          para.gsub!(/<:pb>\s*/,'')
+          para.gsub!(/\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|ftp):\/\/\S+|image)/, 
+            %{<imagedata fileref="#{dir.url.images_local}\/\\1"/>})
+          #para.gsub!(/\{(\S+?\.png) \d+x\d+ \".+?\" \}(?:http:\/\/\S+|image)/,'<image>\1</image>')
+          para.gsub!(/&nbsp;/,' ')
           @char_enc.utf8(para) if @sys.locale =~/utf-?8/i #% utf8
-          if para =~/^0~(\S+)\s+(.+?)$/ # for headers
-            dc=SiSU_scan::Header_scan.new(@md,para).dublin
-            if dc: xml_head(dc[0],dc[1])
-	    end
-	  end
+          if para =~/^0~(\S+)\s+(.+?)\Z/m # for headers
+            d_meta=SiSU_text_utils::Header_scan.new(@md,para).meta
+            if d_meta; xml_head(d_meta)
+	          end
+          end
           @rcdc=true if @rcdc ==false and (para =~/~metadata/ or para =~/1~\s+Document Information/)
           if para !~/(^0~|<ENDNOTES>|<EOF>)/ 
             if para =~/.+?<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>.*/
-              paranum=para[@regx, 3]  #/.+?<~(\d+?)>.*/.match(para)[1]
+              paranum=para[@regx, 3]
               @p_num=SiSU_XML_format::Paragraph_number.new(@md,paranum)
             end
             @sto=SiSU_text_parts::Split_text_object.new(@md,para).lev_segname_para_ocn
@@ -372,38 +369,38 @@ WOK
                 when /^(1)~(?:(\S+))?/
                   xml_markup(para)
                   xml_structure($1,@sto.ocn,para,$2)
-                  para=@sto.lev_para_ocn.heading_body1 #if para =~m
+                  para=@sto.lev_para_ocn.heading_body1
                 when /^(2)~(?:(\S+))?/
                   xml_markup(para)
                   xml_structure($1,@sto.ocn,para,$2)
-                  para=@sto.lev_para_ocn.heading_body2 #if para =~m
+                  para=@sto.lev_para_ocn.heading_body2
                 when /^(3)~(?:(\S+))?/
                   xml_markup(para)
                   xml_structure($1,@sto.ocn,para,$2)
-                  para=@sto.lev_para_ocn.heading_body3 #if para =~m
+                  para=@sto.lev_para_ocn.heading_body3
                 when /^(4)~(\S+)/ # work on see SiSU_text_parts::Split_text_object
                   xml_markup(para)
                   xml_structure($1,@sto.ocn,para,$2)
-                  para=@sto.lev_para_ocn.heading_body4 #if para =~m
+                  para=@sto.lev_para_ocn.heading_body4
                 when /^(5)~(?:(\S+))?/
                   xml_markup(para)
                   xml_structure($1,@sto.ocn,para,$2)
-                  para=@sto.lev_para_ocn.heading_body5 #if para =~m
+                  para=@sto.lev_para_ocn.heading_body5
                 when /^(6)~(?:(\S+))?/
                   xml_markup(para)
                   xml_structure($1,@sto.ocn,para,$2)
-                  para=@sto.lev_para_ocn.heading_body6 #if para =~m
-                #when /^(i1)$/i
+                  para=@sto.lev_para_ocn.heading_body6
+                #when /^(i1)$/
                 #  #format_scroll.gsubBody
                 #  #para=@sto.lev_para_ocn.scrIndent1
-                #when /^(i2)$/i
+                #when /^(i2)$/
                 #  format_scroll.gsubBody
                 #  para=@sto.lev_para_ocn.scrIndent2
-                #when /^(center)$/i
+                #when /^(center)$/
                 #  para.gsub!(/(.+)/,
                 #    %{<center>(\\1)</center>})
                 #  para=@sto.lev_para_ocn.scrPara
-                #when /^(b|bold)$/i
+                #when /^(b|bold)$/
                 #  para.gsub!(/(.+)/,
                 #    %{<b>(\\1)</b>})
                 #  para=@sto.lev_para_ocn.scrPara
@@ -415,7 +412,7 @@ WOK
                 else
                   matched=/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>$/mi.match(para)
                   stamp,ocn=matched[0],matched[1]
-                  if para =~ /<:poem>/
+                  if para =~ /<:verse>/
                     para.gsub!(/#{stamp}/,'')
                     poem_structure(para,ocn)
                   elsif para =~ /<:group>/
@@ -424,7 +421,7 @@ WOK
                   elsif para =~ /<:code>/
                     para.gsub!(/#{stamp}/,'')
                     code_structure(para,ocn)
-                  elsif para =~/<!Th?.+/i # tables come as single block #work area 2005w13
+                  elsif para =~/<!Th?.+/ # tables come as single block #work area 2005w13
                     table=SiSU_Tables::Table_xml.new(para,ocn)
                     para=table.table_split
                     @@xml[:body] << para
@@ -444,12 +441,12 @@ WOK
                 format_scroll=Format_scroll.new(@md,'<br /><a name="owner.details">Owner Details</a>')
                 @@xml[:owner_details]=format_scroll.bold_para
                 para=''
-              elsif para =~/(.*)<:#>(.*)/i
+              elsif para =~/(.*)<:#>(.*)/
                 one, two=$1,$2
                 format_text=Format_text_object.new(one,two)
                 para=format_text.seg_no_paranum
               end
-              para='' if (para =~/<a name="n\d+">/ and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/) # -endnote
+              para='' if para =~/<a name="n\d+">/ and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/ # -endnote
               if para =~/.*<:#>.*$/
                 para=case para
                 when /<:i1>/
@@ -460,15 +457,15 @@ WOK
                   format_text.scr_inden_ocn_e_no_paranum
                 end
               end
-              if para =~/<:center>/i
-                one, two=/(.*)<:center>(.*)/i.match(para)[1,2]
+              if para =~/<:center>/
+                one, two=/(.*)<:center>(.*)/.match(para)[1,2]
                 format_text=Format_text_object.new(one, two)
                 para=format_text.center
               end
-            else #
+            else
             end
             para.gsub!(/<:\S+?>/,'')
-            para.gsub!(/<!.+!>/i,' ') ## Clean Prepared Text
+            para.gsub!(/<!.+!>/,' ')
           end
         end
         @content_flag=true
@@ -490,7 +487,7 @@ WOK
       end
       def pre
         rdf=SiSU_XML_tags::RDF.new(@md)
-        dir=SiSU_Env::Info_dir.new
+        dir=SiSU_Env::Info_env.new
         css=SiSU_Env::CSS_select.new(@md).docbook_xml
         encoding='<?xml version="1.0"?>
 <!DOCTYPE book PUBLIC "-//OASIS//DTD DocBook V5.0//EN"
@@ -498,33 +495,25 @@ WOK
         #encoding='<?xml version="1.0" encoding="utf-8"?>'
         @@xml[:open] =<<WOK
 #{encoding}
-<?xml-stylesheet type="text/css" href="../#{dir.style}/#{css}"?>
+<?xml-stylesheet type="text/css" href="../#{dir.path.style}/#{css}"?>
 #{rdf.comment_xml}
 <book>
 WOK
         @@xml[:head] << "<bookinfo>\n"
-        #@@xml[:body] << "<body>\n"
       end
       def post
         @@xml[:head] << @@xml[:sc]
         @@xml[:head] << "</bookinfo>\n"
-        #@@xml[:body] << "</body>\n"
         @@xml[:close] = "</book>\n"
       end
       def publish
-        content=Array.new
+        content=[]
         data=@data
-        content << @@xml[:open]
-        content << @@xml[:head]
-        content << @@xml[:body]
-        content << @@xml[:metadata]
+        content << @@xml[:open] << @@xml[:head] << @@xml[:body] << @@xml[:metadata]
         content << @@xml[:owner_details] if @md.stmp =~/\w\w/
-        content << @@xml[:tail]
-        content << @@xml[:close]
+        content << @@xml[:tail] << @@xml[:close]
         Output.new(content.to_s,@md).xml
-        @@xml[:head]=Array.new # check whether should be nil
-        @@xml[:body]=Array.new # check whether should be nil
-        @@xml[:tail]=Array.new # check whether should be nil
+        @@xml[:head],@@xml[:body],@@xml[:tail]=[],[],[]
       end
     end
     class Output
@@ -533,17 +522,15 @@ WOK
         @data,@md=data,md
       end
       def xml
-        @sisu=Array.new
-        @data.each do |para| #p
-          #para.strip!
-          para.gsub!(/<:\S+?>/, '')
-          para.gsub!(/<!.+?!>/, '')
+        @sisu=[]
+        @data.each do |para|
+          para.gsub!(/<:\S+?>/,'')
+          para.gsub!(/<!.+?!>/,'')
           para="#{para}\n" unless para.empty?
           @sisu << para
         end
         new_file_data=@sisu.to_s
         @sisu=new_file_data.scan(/.+/)
-        #@sisu.compact!
         filename_plaintext=SiSU_Env::SiSU_file.new(@md).mkdir
         filename_xml=SiSU_Env::SiSU_file.new(@md,@md.fn[:docbook]).mkfile
         @sisu.each {|para| filename_xml.puts para}
@@ -552,8 +539,8 @@ WOK
     end
     class Tidy
       def initialize(md,dir)
-        @md,@dir=md,dir
-        @prog=SiSU_Env::Info_program.new #(md.fns) #if md
+        @md,@env=md,dir
+        @prog=SiSU_Env::Info_program.new
       end
       def xml
         if @prog.tidy !=false
@@ -562,7 +549,7 @@ WOK
             tell.colorize unless @md.cmd =~/q/
             tell.grey_open unless @md.cmd =~/q/
             tidyfile='/dev/null' #don't want one or screen output, check for alternative flags
-            tidy=SiSU_Env::System_call.new("#{@dir.data_o}/#{@md.fnb}/#{@md.fn[:docbook]}",tidyfile)
+            tidy=SiSU_Env::System_call.new("#{@env.path.output}/#{@md.fnb}/#{@md.fn[:docbook]}",tidyfile)
             tidy.well_formed?
             tell.p_off unless @md.cmd =~/q/
           end
