@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: base formatting template for html generation
 
@@ -51,20 +51,20 @@ module SiSU_HTML_Format
   include SiSU_Param
   include SiSU_Viz
   #include SiSU_HTML_Format
-  require SiSU_lib + '/common_xml'
+  require SiSU_lib + '/shared_xml'
   include SiSU_XML_tags
-  require SiSU_lib + '/common_text'
+  require SiSU_lib + '/shared_txt'
   include SiSU_text_utils
   class Paragraph_number
     def initialize(md,paranum)
       @md=md
-      @paranum=paranum[/(\d+)/im,1]
+      @paranum=paranum[/(\d+)/m,1]
       @paranum ||=''
-      @paranum='' if @paranum =~/^0$/
+      @paranum='' if @md.mod.inspect =~/--no-ocn/
     end
     def ocn_display
-      ocn_class=if @md.cmd =~/[phH]\S*0/: 'ocn_off'
-      else                               'ocn'
+      ocn_class=if @md.mod.inspect =~/--no-ocn/; 'ocn_off'
+      else                                 'ocn'
       end
       @paranum.gsub(/^(\d+|)$/,
         %{  <p class="#{ocn_class}">
@@ -73,11 +73,9 @@ module SiSU_HTML_Format
     end
     def name
       %{<a name="#@paranum" />}
-      #%{<a name="#@paranum"></a>}
     end
     def id #w3c? "tidy" complains about numbers as identifiers ! annoying
       %{id="o#@paranum"}
-      #%{id="#@paranum"}
     end
     def goto
       %{<a href="##@paranum">}
@@ -147,7 +145,6 @@ module SiSU_HTML_Format
     @@credits=SiSU_Viz::Credits.new
     @@js=SiSU_Viz::Javascript.new
     @@php=SiSU_Viz::Php.new
-    #@@date=SiSU_Env::Info_date.new
     attr_reader :md,:sfx,:pdf,:rdf,:margin,:paragraph,:table,:banner,:url,:png,:txt,:color,:font,:nav_txt,:nav_png,:credits,:credit,:js,:php,:seg_name_html,:metalink,:tocband_scroll,:tocband_segtoc,:link,:linkname #,:date
     def initialize(md='')
       @md=md
@@ -159,7 +156,7 @@ module SiSU_HTML_Format
       @seg_name_html=(SiSU_HTML::Source::Seg.new.seg_name_html || [])
       @seg_name_html_tracker=(SiSU_HTML::Source::Seg.new.seg_name_html_tracker || [])
       case @md.file_type
-      when /php/: @index='index' # @index="index.php"
+      when /php/; @index='index' # @index="index.php"
       else        @index='index'
       end
       @metalink='#metadata'
@@ -169,8 +166,6 @@ module SiSU_HTML_Format
       %{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
 "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">\n}
-#      %{<!DOCTYPE HTML PUBLIC "-//W3C//Dtd HTML 4.0 Transitional//EN">
-#<html>\n}
     end
     def toc_head_escript #embedded script in this case PHP
       # %{<p>PHP or other embedded script for object persistence may go HERE</p>}
@@ -272,6 +267,11 @@ WOK
 </td>
 <td align="center" bgcolor=#{@color.band2}>
   #{@nav_txt.pdfs}
+</td>
+<td align="center" bgcolor=#{@color.band2}>
+  <a href="#{@md.fn[:odf]}" target="_top" #{@js.odf}>
+    #{@nav_txt.odf}
+  </a>
 </td>}
       else ''
       end
@@ -303,6 +303,11 @@ WOK
 </td>
 <td align="center" bgcolor=#{@color.band2}>
   #{@nav_txt.pdfs}
+</td>
+<td align="center" bgcolor=#{@color.band2}>
+  <a href="#{@md.fn[:odf]}" target="_top" #{@js.odf}>
+    #{@nav_txt.odf}
+  </a>
 </td>}
       else ''
       end
@@ -330,6 +335,11 @@ WOK
 </td>
 <td align="center" bgcolor=#{@color.band2}>
   #{@nav_txt.pdfs}
+</td>
+<td align="center" bgcolor=#{@color.band2}>
+  <a href="#{@md.fn[:odf]}" target="_top" #{@js.odf}>
+    #{@nav_txt.odf}
+  </a>
 </td>}
       else ''
       end
@@ -373,6 +383,11 @@ WOK
 </td>
 <td align="center" bgcolor=#{@color.band2}>
   #{@nav_txt.pdfs}
+</td>
+<td align="center" bgcolor=#{@color.band2}>
+  <a href="#{@md.fn[:odf]}" target="_top" #{@js.odf}>
+    #{@nav_txt.odf}
+  </a>
 </td>}
       else ''
       end
@@ -469,7 +484,7 @@ WOK
       #document_version_hold
     end
     def links_guide_vertical_open
-      url=if defined? @url.hp: @url.hp
+      url=if defined? @url.hp; @url.hp
       else @url.home
       end
       %{<div id="vertical_links">
@@ -490,7 +505,7 @@ WOK
 <!- quick ref -!>}
     end
     def links_guide_horizontal_open
-      url=if defined? @url.hp: @url.hp
+      url=if defined? @url.hp; @url.hp
       else @url.home
       end
       %{<div id="horizontal_links">
@@ -511,7 +526,7 @@ WOK
 <!- quick ref -!>}
     end
     def links_guide_open(type='horizontal')
-      if type=='vertical': links_guide_vertical_open
+      if type=='vertical'; links_guide_vertical_open
       else                 links_guide_horizontal_open
       end
     end
@@ -541,7 +556,7 @@ WOK
 <!- quick ref -!>}
     end
     def links_guide_open_old
-      url=if defined? @url.hp: @url.hp
+      url=if defined? @url.hp; @url.hp
       else @url.home
       end
       %{  <br />
@@ -908,10 +923,15 @@ WOK
 </td>
 <td align="center" bgcolor=#{@color.band2}>
   #{@nav_txt.pdfs}
+</td>
+<td align="center" bgcolor=#{@color.band2}>
+  <a href="#{@md.fn[:odf]}" target="_top" #{@js.odf}>
+    #{@nav_txt.odf}
+  </a>
 </td>}
       else ''
       end
-      dir=SiSU_Env::Info_dir.new(@md.fns)
+      dir=SiSU_Env::Info_env.new(@md.fns)
       sum='manifest'
       concord=concordance_link(@nav_txt.concordance)
       if @md.fns =~ /\.[_-]?sst$/
@@ -1022,36 +1042,36 @@ WOK
   <font size="2">}
     end
     def header_advert_local_1
-      dir=SiSU_Env::Info_dir.new(@fns)
+      dir=SiSU_Env::Info_env.new(@fns)
       %{  <center>
 <table summary="image" border="0" cellpadding="3" cellspacing="0" align="center">
 <tr><td align="center" bgcolor="white">
   <a href="http://#{@md.ad_url}#@sfx" target="_top">
-    <img border="0" src="#{dir.url_images_local}/#{@md.ad_png}" alt="#{@md.ad_alt}">
+    <img border="0" src="#{dir.url.images_local}/#{@md.ad_png}" alt="#{@md.ad_alt}">
   </a>
   <p />
 #{@table.close}
 </center>}
     end
     def header_advert_local_2
-      dir=SiSU_Env::Info_dir.new(@fns)
+      dir=SiSU_Env::Info_env.new(@fns)
       %{  <center>
 <table summary="image" border="0" cellpadding="3" cellspacing="0" align="center">
 <tr><td align="center" bgcolor="white">
   <a href="#{@md.ad_url}#@sfx" target="_top">
-    <img border="0" src="#{dir.url_images_local}/#{@md.ad_png}" alt="#{@md.ad_alt}">
+    <img border="0" src="#{dir.url.images_local}/#{@md.ad_png}" alt="#{@md.ad_alt}">
   </a>
   <p />
 #{@table.close}
 </center>}
     end
     def header_advert_external
-      dir=SiSU_Env::Info_dir.new(@fns)
+      dir=SiSU_Env::Info_env.new(@fns)
       %{  <center>
 <table summary="image" border="0" cellpadding="3" cellspacing="0" align="center">
 <tr><td align="center" bgcolor="white">
   <a href="#{@md.ad_url}#@sfx" target="external">
-    <img border="0" src="#{dir.url_images_local}/#{@md.ad_png}" alt="#{@md.ad_alt}">
+    <img border="0" src="#{dir.url.images_local}/#{@md.ad_png}" alt="#{@md.ad_alt}">
   </a>
   <p />
 #{@table.close}
@@ -1116,28 +1136,25 @@ WOK
       @md,@one,@two,@three=md,txt[0],txt[1],txt[2]
       rgx=/[1-6-]~/
       @one_stripped=@one.gsub(rgx,'') if @one =~rgx
-      @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
-      rgx=/~\{[\d*+]+\s+(.+?)<#{@@dp}>\}~/ #problem introduced
+      @@dp ||=SiSU_Env::Info_env.new.digest.pattern
+      rgx=/~[{\[][\d*+]+\s+(.+?)<#{@@dp}>[}\]]~/ #problem introduced
       @one_stripped=@one.gsub(rgx,'\1') if @one =~rgx #problem introduced
       @link,@linkname=txt[0],txt[1]
       @format,parablock=txt[0],txt[1]
-      @parablock=if parablock=~/\S+/
-      #@parablock=@one=if parablock=~/\S+/
-        wrap=SiSU_text_utils::Paragraph.new(parablock,70,4)
+      @parablock=if parablock=~/\S+/ and parablock !~/<!Th?¡ /m
+        wrap=SiSU_text_utils::Wrap.new(parablock,70,4)
         wrap.line_wrap
       else parablock
       end
-      #p @parablock.class if parablock
-      #p @parablock if parablock
       if txt[2]=~/\d+/
-        @paranum=txt[2][/(\d+)/im,1] # unless paranum =~/#/
+        @paranum=txt[2][/(\d+)/m,1] # unless paranum =~/#/
         @p_num=SiSU_HTML_Format::Paragraph_number.new(@md,@paranum)
         @para_id=Paragraph_id_ocn.new(@md,@paranum) #used by table version
       end
       @headname=''
-      if @format =~ /\d~(\S+)/im
-        headname=$1 #format[/\d~(\S+)/im,1]
-        @headname=if headname =~/^[a-zA-Z]/: %{<a name="#{headname}" id="#{headname}"></a>} #consider: h_#{headname}
+      if @format =~ /\d~(\S+)/
+        headname=$1 #format[/\d~(\S+)/m,1]
+        @headname=if headname =~/^[a-zA-Z]/; %{<a name="#{headname}" id="#{headname}"></a>} #consider: h_#{headname}
         else %{<a name="h#{headname}" id="h#{headname}"></a>}
         end
       end
@@ -1150,8 +1167,6 @@ WOK
       @font=@@font           #SiSU_Viz::Font.new
       @table=@@table         #SiSU_Viz::Table.new
       @color=@@color         #SiSU_Viz::Color.new
-      #file_base=@one.gsub(/\.(html|pdf|php)/,'') if @one =~/\.\.\/\S+/
-      #@link,@linkname=file_base,@two
     end
     def para_form                                                                # regular paragraphs shaped here
       ul=ulc=''
@@ -1176,7 +1191,6 @@ WOK
     def center
       @tag,@class='p','center'
       para_form
-      #"<center>#@one#@two</center>" #watch removed and problems may arise 2005w11
     end
     def bold
       @tag,@class='p','bold'
@@ -1221,15 +1235,15 @@ WOK
     def gsub_body
       case @one
       when /^(?:<:i[12]>\s*)?\((i+|iv|v|vi+|ix|x|xi+)\)/
-        @one.gsub!(/^\((i+|iv|v|vi+|ix|x|xi+)\)/,%{<b>(\\1)</b>})
-        @one.gsub!(/^(<:i[12]>)\s*\((i+|iv|v|vi+|ix|x|xi+)\)/,%{\\1<b>(\\2)</b>})
+        @one.gsub!(/^\((i+|iv|v|vi+|ix|x|xi+)\)/,'<b>(\1)</b>')
+        @one.gsub!(/^(<:i[12]>)\s*\((i+|iv|v|vi+|ix|x|xi+)\)/,'\1<b>(\2)</b>')
       when /^(?:<:i[12]>\s*)?\(?(\d|[a-z])+\)/
-        @one.gsub!(/^\((\d+|[a-z])+\)/,%{<b>(\\1)</b>})
-        @one.gsub!(/^(<:i[12]>)\s*\((\d+|[a-z])+\)/,%{\\1<b>(\\2)</b>})
+        @one.gsub!(/^\((\d+|[a-z])+\)/,'<b>(\1)</b>')
+        @one.gsub!(/^(<:i[12]>)\s*\((\d+|[a-z])+\)/,'\1<b>(\2)</b>')
       when /^\s*\d{1,3}\.\s/
-        @one.gsub!(/^\s*(\d+\.)/,%{<b>\\1</b>})
+        @one.gsub!(/^\s*(\d+\.)/,'<b>\1</b>')
       when /^\s*[A-Z]\.\s/
-        @one.gsub!(/^\s*([A-Z]\.)/,%{<b>\\1</b>})
+        @one.gsub!(/^\s*([A-Z]\.)/,'<b>\1</b>')
       end
     end
     def bold_para
