@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: html generation, html pre-processing
 
@@ -54,18 +54,18 @@ module SiSU_Tune
   include SiSU_Env
   include SiSU_Screen
   @@line_mode=''
-  @@endnote_array=Array.new
+  @@endnote_array=[]
   @@endnote_call_counter=1
-  @@table_align=%{<table summary='' width="96%" border="0" bgcolor="white" cellpadding="0" col="3">
+  @@table_align='<table summary='' width="96%" border="0" bgcolor="white" cellpadding="0" col="3">
 <tr ...><td width="2%" align="right">
 &nbsp\;</td>
-<td width="94%" valign="top" align="justify">}
-  @@table_align_close=%{</td>
+<td width="94%" valign="top" align="justify">'
+  @@table_align_close='</td>
 <td width="4%" align="right" valign="top"> 
 <font size="1" color="#777777">
-&nbsp;&nbsp;&nbsp;</font> </td></tr></table>}
+&nbsp;&nbsp;&nbsp;</font> </td></tr></table>'
   @@counter,@@column,@columns=0,0,0
-  class MyOutput
+  class Output
     def initialize(data,md)
       @data,@md=data,md
       @cX=SiSU_Screen::Ansi.new(@md.cmd).cX
@@ -73,7 +73,7 @@ module SiSU_Tune
     def hard_output
       my_make=SiSU_Env::Create_file.new(@md.cmd,@md.fns)
       @filename_tune=my_make.file_tune
-      data=Array.new
+      data=[]
       @data.each{|x| x.strip; data << x if not x.empty?} #1.9 array?
       data.each do |para|
         @filename_tune.puts para, "\n" #if para !~/¡/
@@ -178,16 +178,16 @@ module SiSU_Tune
       @html
     end
   end
-  class MyTune
+  class Tune
     @@dp=nil
     def initialize(data,md)
       @data,@md=data,md
       @url=SiSU_Viz::Url.new
       @color=SiSU_Viz::Color.new
       @icon=SiSU_Viz::Icon.new
-      @env=SiSU_Env::Info_dir.new(@md.fns)
+      @env=SiSU_Env::Info_env.new(@md.fns)
       @sys=SiSU_Env::System_call.new
-      @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
+      @@dp ||=SiSU_Env::Info_env.new.digest.pattern
       #@utf8=SiSU_character_encode::UTF8 #.new
     end
     def songsheet
@@ -195,30 +195,30 @@ module SiSU_Tune
         @cX=SiSU_Screen::Ansi.new(@md.cmd).cX
         tell=SiSU_Screen::Ansi.new(@md.cmd,'Tune')
         tell.txt_grey unless @md.cmd =~/q/
-        #print "\t#{@cX.grey}Tune#{@cX.off}\n" 
-        data=MyTune.new(@data,@md).endnotes_html
-        data=MyTune.new(data,@md).url_markup
+        data=Tune.new(@data,@md).endnotes_html
+        data=Tune.new(data,@md).url_markup
         if @sys.locale =~/utf-?8/i
-          data=MyTune.new(data,@md).utf8_markup 
+          data=Tune.new(data,@md).utf8_markup 
         end
-        MyTune.new(@data,@md).output
-        #Hard Output Tune Optional on/off here (4 lines) ->
-          data=MyOutput.new(data,@md).hard_output
-          data=MyOutput.new(data,@md).marshal
-      rescue: SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
+        if @md.cmd =~/M/  #Hard Output Tune Optional on/off here
+          data=Output.new(data,@md).hard_output
+          Output.new(data,@md).marshal
+        end
+        tuned=Tune.new(@data,@md).output
+      rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
       ensure
       end
     end
     def para_numbers
       data=@data
-      @tuned_file=Array.new
+      @tuned_file=[]
       data.each do |para|
-        para.gsub!(/(\d~(\S+))/,%{\\1<a name="H#\\2">#\\2.</a>&nbsp;})
+        para.gsub!(/(\d~(\S+))/,'\1<a name="H#\2">#\2.</a>&nbsp;')
         @tuned_file << para
       end
     end
     def utf8_markup
-      @tuned_file=Array.new
+      @tuned_file=[]
       @data.each do |para|
         #@utf8.new(para).html
         #@utf8.html(@para)
@@ -234,105 +234,109 @@ module SiSU_Tune
     end
     def url_markup
       data=@data
-      @tuned_file=Array.new
+      @tuned_file=[]
       data.each do |para|
-        para.gsub!(/<:name\#(\S+?)>/,%{<a name="\\1"></a>})
+        para.gsub!(/<:name\#(\S+?)>/,'<a name="\1"></a>')
         para.gsub!(/<-#>/,'')
         para.gsub!(/<:p[bn]>/,'')
-        para.gsub!(/<(p|br)>/i,%{<\\1 />})
-        para.gsub!(/<:br>/i,%{<br />})
+        para.gsub!(/<(p|br)>/,'<\1 />')
+        para.gsub!(/<:br>/,'<br />')
         if para =~/<::\s+/ #watch
-          para.gsub!(/<::\s+(\S+?)\s+!>/i,
-            %{<img src="#{@env.url_images}/c_\\1.png" alt="\\1" width="14" height="14" align="bottom" border="0">})
+          para.gsub!(/<::\s+(\S+?)\s+!>/,
+            %{<img src="#{@env.url.images}/c_\\1.png" alt="\\1" width="14" height="14" align="bottom" border="0">})
         end
         if para =~/<:image\s+/
-          para.gsub!(/<:image\s+(http\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+>/i,
-            %{<a href="\\1"><img src="#{@env.url_images_local}/\\2" \\3 \\4 naturalsizeflag="0" align="bottom" border="0"></a>})
-          para.gsub!(/<:image\s+(http\S+)\s+(\S+)\s+>/i,
-            %{<a href="\\1"><img src="#{@env.url_images_local}/\\2" naturalsizeflag="0" align="bottom" border="0"></a>})
-          para.gsub!(/<:image\s+(\S+)\s+(\S+)\s+(\S+)\s+>/i,
-            %{<img src="#{@env.url_images_local}/\\1" \\2 \\3 naturalsizeflag="0" align="bottom" border="0">})
-          para.gsub!(/<:image\s+(\S+)\s+>/i,
-            %{<img src="#{@env.url_images_local}/\\1" naturalsizeflag="0" align="bottom" border="0">})
+          para.gsub!(/<:image\s+(http\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s+>/,
+            %{<a href="\\1"><img src="#{@env.url.images_local}/\\2" \\3 \\4 naturalsizeflag="0" align="bottom" border="0"></a>})
+          para.gsub!(/<:image\s+(http\S+)\s+(\S+)\s+>/,
+            %{<a href="\\1"><img src="#{@env.url.images_local}/\\2" naturalsizeflag="0" align="bottom" border="0"></a>})
+          para.gsub!(/<:image\s+(\S+)\s+(\S+)\s+(\S+)\s+>/,
+            %{<img src="#{@env.url.images_local}/\\1" \\2 \\3 naturalsizeflag="0" align="bottom" border="0">})
+          para.gsub!(/<:image\s+(\S+)\s+>/,
+            %{<img src="#{@env.url.images_local}/\\1" naturalsizeflag="0" align="bottom" border="0">})
         end
         if para =~/\{.+?\}((?:http|ftp)\S+|image)/
           @word_mode=para.scan(/\{.+?\}(?:(?:https?|ftp)\S+|image)|\S+/)
-          word_mode=SiSU_Tune::MyUrls.new(@word_mode,@md).urls
+          word_mode=SiSU_Tune::Tune_urls.new(@word_mode,@md).urls
           words=word_mode.join(' ')
           para.gsub!(/.+/,words)
         end
         if (para !~/^0~/)
           para.gsub!(/\\copyright/i,%{<sup>&copy;</sup>})
           if (para !~/\<:ad\s+\.\.\//)
-            para.gsub!(/\<:ad\s+(\S+)?\s+(\S+\.png)\s+(.+)?\;\s+(.+)?\;\s*!\>/i,
-              %{\n<center><a href="http:\/\/\\1" target="external"><img src="#{@env.url_images_local}/\\2" alt="\\3"></a></center>\n})
+            para.gsub!(/\<:ad\s+(\S+)?\s+(\S+\.png)\s+(.+)?\;\s+(.+)?\;\s*!\>/,
+              %{\n<center><a href="http:\/\/\\1" target="external"><img src="#{@env.url.images_local}/\\2" alt="\\3"></a></center>\n})
           else
-            para.gsub!(/\<:ad\s+(\S+)?\s+(\S+\.png)\s+(.+)?\;\s+(.+)?\;\s*\>/i,
-              %{\n<center><a href="\\1" target="_top"><img src="#{@env.url_images_local}/\\2" alt="\\3"></a></center>\n})
+            para.gsub!(/\<:ad\s+(\S+)?\s+(\S+\.png)\s+(.+)?\;\s+(.+)?\;\s*\>/,
+              %{\n<center><a href="\\1" target="_top"><img src="#{@env.url.images_local}/\\2" alt="\\3"></a></center>\n})
           end
-          para.gsub!(/!pick/i, %{<img border="0" height="15" width="15" src="#{@env.url_images}/#{@icon.choice}" alt="stellar">})
-          para.gsub!(/!new/i, %{&nbsp;<img border="0" height="15" width="15" src="#{@env.url_images}/#{@icon.new}" alt="new">})
-          para.gsub!(/<:h(.{1,7}?)>/i,%{<a href="#h\\1">\\1</a>})
-          para.gsub!(/<:to(\d{1,7}?)>/i,%{<a href="#to\\1">to&nbsp;{&nbsp;\\1&nbsp;}</a> })
+          para.gsub!(/!pick/, %{<img border="0" height="15" width="15" src="#{@env.url.images}/#{@icon.choice}" alt="stellar">})
+          para.gsub!(/!new/, %{&nbsp;<img border="0" height="15" width="15" src="#{@env.url.images}/#{@icon.new}" alt="new">})
+          para.gsub!(/<:h(.{1,7}?)>/,'<a href="#h\1">\1</a>')
+          para.gsub!(/<:to(\d{1,7}?)>/,'<a href="#to\1">to&nbsp;{&nbsp;\1&nbsp;}</a> ')
           if (para =~/\b\S+\@\S+?\.\S+/ and para !~/(\"\S+\@\S+?\.\S+\"|>\S+\@\S+?\.\S+?<)/)
-            para.gsub!(/\b(\S+\@\S+?\.\S+)(\s)/i,%{\<a href="mailto:\\1">\\1</a>\\2})
+            para.gsub!(/\b(\S+\@\S+?\.\S+)(\s)/,'<a href="mailto:\1">\1</a>\\2')
           end
           if (para !~/(\"\w+:\/\/\S+?\"|>\s*\w+:\/\/\w+?\S*<)/) #url markup http etc.
             if para=~/\w+:\/\/\S+?\.\S+?[.,] /
-              para.gsub!(/(\w+:\/\/\S+?\.\S+?)([.,] )/i,%{<a href="\\1" target="_top">\\1</a>\\2}) #full stops ! have been a bother
+              para.gsub!(/(\w+:\/\/\S+?\.\S+?)([.,] )/,'<a href="\1" target="_top">\1</a>\2') #full stops ! have been a bother
             else
-              para.gsub!(/(\w+:\/\/\S+?\.\S+)/i, %{<a href="\\1" target="_top">\\1</a>})
+              para.gsub!(/(\w+:\/\/\S+?\.\S+)/, '<a href="\1" target="_top">\1</a>')
             end
           end
-          if (para =~/[ ^](?:https?|ftp):\/\/\S+/i) #url markup http leftovers watch carefully may accept too much 2004w46
+          if (para =~/[ ^](?:https?|ftp):\/\/\S+/) #url markup http leftovers watch carefully may accept too much 2004w46
             if para=~/([ ^])((?:https?|ftp):\/\/\S+?)([\.,] )/
-            para.gsub!(/([ ^])((?:https?|ftp):\/\/\S+?)([\.,] )/i,%{\\1<a href="\\2" target="_top">\\2</a>\\3}) #full stops ! have been a bother
+            para.gsub!(/([ ^])((?:https?|ftp):\/\/\S+?)([\.,] )/,'\1<a href="\2" target="_top">\2</a>\3') #full stops ! have been a bother
             else
-              para.gsub!(/([ ^])((?:https?|ftp):\/\/\S+)/i,%{\\1<a href="\\2" target="_top">\\2</a>})
+              para.gsub!(/([ ^])((?:https?|ftp):\/\/\S+)/,'\1<a href="\2" target="_top">\2</a>')
             end
           end
           if (para =~/..\/\S+/ and para !~/(\"..\/\S+?\"|>\s*..\/\S+<)/)
-            para.gsub!(/(\.\.\/\S+)/i,%{<a href="\\1">\\1</a>})
+            para.gsub!(/(\.\.\/\S+)/,'<a href="\1">\1</a>')
           end
-          para.gsub!(/<a href="\.\.\//i,%{<a href="#{@url.site}/})
+          para.gsub!(/<a href="\.\.\//,%{<a href="#{@url.site}/})
         end
         @tuned_file << para
       end
     end
     def endnotes_html
       data=@data
-      @tuned_file=Array.new
+      @tuned_file=[]
       data.each do |para|
-        para.gsub!(/~\{(\d+) (.+?) <#{@@dp}>\}~/i,
-          %{&nbsp;<a name="-\\1" href="#_\\1">&nbsp;<sup>\\1</sup>&nbsp;</a> } +  #note- endnote-
-          %{~\{\\1 <a name="_\\1" href="#-\\1">&nbsp;<sup>\\1.</sup></a> \\2 \}~}) #endnote- note- (careful may have switched)
-        para.gsub!(/~\{([*+]+) (.+?) <#{@@dp}>\}~/i,
-          %{&nbsp;<a name="-\\1" href="#_\\1">&nbsp;<sup>\\1</sup>&nbsp;</a> } +  #note- endnote-
-          %{~\{\\1 <a name="_\\1" href="#-\\1">&nbsp;<sup>\\1</sup></a> \\2 \}~}) #endnote- note- (careful may have switched)
+        para.gsub!(/(~[{])(\d+) (.+?) <#{@@dp}>([}]~)/,
+          '&nbsp;<a name="-\2" href="#_\2">&nbsp;<sup>\2</sup>&nbsp;</a> ' +  #note- endnote-
+          '\1\2 <a name="_\2" href="#-\2">&nbsp;<sup>\2.</sup></a> \3 \4') #endnote- note- (careful may have switched)
+        para.gsub!(/(~\[)([*+]\d+) (.+?) <#{@@dp}>(\]~)/,
+          '&nbsp;<a name="-\2" href="#_\2">&nbsp;<sup>\2</sup>&nbsp;</a> ' +  #note- endnote-
+          '\1\2 <a name="_\2" href="#-\2">&nbsp;<sup>\2.</sup></a> \3 \4') #endnote- note- (careful may have switched)
+        para.gsub!(/(~\{)([*+]+) (.+?) <#{@@dp}>(\}~)/,
+          '&nbsp;<a name="-\2" href="#_\2">&nbsp;<sup>\2</sup>&nbsp;</a> ' +  #note- endnote-
+          '\1\2 <a name="_\2" href="#-\2">&nbsp;<sup>\2</sup></a> \3 \4') #endnote- note- (careful may have switched)
           @tuned_file << para
         end
     end
     def output
       data=@data
-      @tuned_file=Array.new
+      @tuned_file=[]
       data.each do |para|
         para.strip!
         para.chomp!
         @tuned_file << para
       end
-      @tuned_file << "\n<EOF>" if (@md.fns =~/\.sst0/i) #remove
+      @tuned_file << "\n<EOF>" if (@md.fns =~/\.sst0/) #remove
+      @tuned_file
     end
   end
-  class MyUrls
+  class Tune_urls
     def initialize(data,md)
       @data,@md=data,md
       @url=SiSU_Viz::Url.new
       @color=SiSU_Viz::Color.new
       @icon=SiSU_Viz::Icon.new
-      @env=SiSU_Env::Info_dir.new(@md.fns)
+      @env=SiSU_Env::Info_env.new(@md.fns)
     end
     def urls
-      @words=Array.new
+      @words=[]
       @data.each do |word|
         @words << if word=~/\{(.+?)\}((?:https?|ftp)\S+|image)/
           if word =~/\{(.+?)\}((?:https?|ftp)\S+|image)([.,](?:\s|$))/
@@ -341,15 +345,15 @@ module SiSU_Tune
             d=''
           end
           case m 
-          when /\.png|\.jpg|c=|\d+x\d+/
+          when /\.png|\.jpg|\.gif|c=|\d+x\d+/
             w,h=/(\d+)x(\d+)/.match(m).captures if m =~/\d+x\d+/ 
             w=%{width="#{w}"} if w
             h=%{height="#{h}"} if h
-            c=m[/"(.+?)"/im, 1]
+            c=m[/"(.+?)"/m,1]
             caption=%{<br /><p class="caption">#{c}</p>} if c
             png=m.scan(/\S+/)[0]
-            image_path=if @md.fns =~/\.-ss[tm]$/: @env.url_images_external
-            else                               @env.url_images_local
+            image_path=if @md.fns =~/\.-ss[tm]$/; @env.url.images_external
+            else                                  @env.url.images_local
             end
             ins=if u and u.strip !~/^image$/ 
               %{<a href="#{u}"><img src="#{image_path}/#{png}" #{w} #{h} naturalsizeflag="0" align="bottom" border="0"></a>#{caption}}
@@ -357,7 +361,7 @@ module SiSU_Tune
             end
             word.gsub!(/\{.+?\}((?:https?|ftp)\S+|image)/,ins)
           else
-            link=m[/(.+)/im]
+            link=m[/(.+)/m]
             png=m.scan(/\S+/)[0].strip
             link=link.strip
             ins=%{<a href="#{u}">#{link}</a>#{d}}
