@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: document summary processing, available outputs and metadata
 
@@ -57,41 +57,38 @@ module SiSU_Manifest
   class Source
     def initialize(opt)
       @opt=opt
-      @md=SiSU_Param::Parameters.new(@opt).get
-      @fnb=@md.fnb
       l=SiSU_Env::Standardise_language.new.file_to_language(@opt.fns)
       @doc_language=l[:l]
     end
     def read
       begin
+        @env=SiSU_Env::Info_env.new(@opt.fns)
         @md=SiSU_Param::Parameters.new(@opt).get
-        @env=SiSU_Env::Info_dir.new(@opt.fns)
-        path=SiSU_Env::Info_dir.new(@opt.fns)
-        xbrowser=@env.web_browser
-        browser=@env.console_web_browser
-        webserv_url=path.tell_output_location
+        SiSU_Env::Info_skin.new(@md).select
+        xbrowser=@env.program.web_browser
+        browser=@env.program.console_web_browser
+        webserv_url=@env.path.url.output_tell
         url_html="#{webserv_url}/#{@md.fnb}/#{@md.fn[:manifest]}"
         tell=SiSU_Screen::Ansi.new(@opt.cmd,'Manifest',"#{xbrowser} #{url_html}")
         tell.green_hi_blue unless @opt.cmd =~/q/
         tell=SiSU_Screen::Ansi.new(@opt.cmd,"#{browser} #{url_html}")
         tell.grey_tab if @opt.cmd =~/v/i
         Output_Info.new(@md).check_output
-      rescue: SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
       end
     end
     private
     class Output_Info <Source
       def initialize(md)
-        @manifest=Hash.new
-        @manifest[:txt],@manifest[:html]=Array.new,Array.new
+        @manifest={ :txt=>[],:html=>[] }
         @md,@fns=md
-        @env=SiSU_Env::Info_dir.new(@md.fns)
+        @env=SiSU_Env::Info_env.new(@md.fns)
         @fnb=@md.fnb
-        out=@env.data_o
-        @base_url="#{@env.output_links_path[:url_root]}/#@fnb"
+        out=@env.path.output
+        @base_url="#{@env.url.root}/#@fnb"
         @base_path="#{out}/#@fnb"
-        @@dg ||=SiSU_Env::Info_dir.new.digest
+        @@dg ||=SiSU_Env::Info_env.new.digest.type
         @dg=@@dg
         l=SiSU_Env::Standardise_language.new.file_to_language(@md.fns)
         @language=l[:l]
@@ -106,31 +103,31 @@ module SiSU_Manifest
       end
       def summarize(id,file)
         size=(File.size("#{@base_path}/#{file}")/1024.00).to_s
-        kb=/([0-9]+\.[0-9]{0,1})/im.match(size)[1]
+        kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
         @manifest[:txt] << "#{file} #{id} #{kb}\n"
         @manifest[:html] << %{<tr><th class="left"><p class="bold"><a href="#{file}">#{file}</a></p></th><td><p class="norm">#{id}</p><p class="tiny"><a href="#@base_url/#{file}">#@base_url/#{file}</a></p></td><td class="right"><p class="right">#{kb}</p></td></tr>\n}
       end
       def summarize_source(id,file)
         sys=SiSU_Env::System_call.new
-        dgst =if @dg =~/^sha(?:2|256)$/: sys.sha256("#{@base_path}/#{file}")
+        dgst =if @dg =~/^sha(?:2|256)$/; sys.sha256("#{@base_path}/#{file}")
         else                             sys.md5("#{@base_path}/#{file}")
         end
         tell=SiSU_Screen::Ansi.new(@md.cmd,"#{dgst[1]} #{file}")
         tell.warn if @md.cmd =~/[vVM]/
         size=(File.size("#{@base_path}/#{file}")/1024.00).to_s
-        kb=/([0-9]+\.[0-9]{0,1})/im.match(size)[1]
+        kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
         @manifest[:txt] << "#{file} #{id} #{kb}\n"
         @manifest[:html] << %{<tr><th class="left"><p class="tiny">#{id}:</p> <p class="norm"><a href="#{file}">#{file}</a></p><p class="tiny"><a href="#@base_url/#{file}">#@base_url/#{file}</a></p></th><td class="right"><p class="tiny">#{dgst[1]}</p></td><td class="right"><p class="right">#{kb}</p></td></tr>\n}
       end
       def languages(id,file)
         flv=@env.published_manifests?(@base_path)
-        @manifest[:html] << %{<tr><th class="left"><p class="bold"><p class="bold">\n}
+        @manifest[:html] << %{<tr><th class="left"><div id="horizontal_links"><ul id="horizontal">\n}
         flv.each do |l|
           lang=SiSU_Translate::Source.new(@md,@language,l[:l]).language_list
           @manifest[:txt] << "#{l[:m]} #{lang}\n"
-          @manifest[:html] << %{<a href="#{l[:m]}">#{lang}</a>&nbsp;&nbsp;&nbsp; }
+          @manifest[:html] << %{<li class="norm"><a href="#{l[:m]}">#{lang}</a>&nbsp;&nbsp;&nbsp;</li>}
         end
-        @manifest[:html] << %{</p></th></tr>\n}
+        @manifest[:html] << %{</ul></div></th></tr>\n}
       end
       def published_languages(id,file)
         flv=@env.published_manifests?(@base_path)
@@ -144,8 +141,8 @@ module SiSU_Manifest
         @manifest[:html] << %{<tr><th class="left"><p class="bold">#{id}:</p></th><td><p class="left">#{info}</p></td></tr>\n}
       end
       def links(url,lnk,target)
-        static=if url =~/^\.\//: url.gsub(/^\.(\.)?/,@base_url)
-        elsif url =~/^\.\.\//:   url.gsub(/^\.(\.)?/,@env.output_links_path[:url_root])
+        static=if url =~/^\.\//; url.gsub(/^\.(\.)?/,@base_url)
+        elsif url =~/^\.\.\//;   url.gsub(/^\.(\.)?/,@env.url.root)
         else                     url                            
         end
         @manifest[:html] << %{<tr><th class="left"><p class="norm"><a href="#{url}">#{lnk}</a></p><p class="tiny"><a href="#{static}">#{static}</a></p></th></tr>\n}
@@ -176,18 +173,18 @@ module SiSU_Manifest
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:pdf_p]}")==true
-          id,file='PDF (portrait)',@md.fn[:pdf_p]
+          id,file='PDF (portrait) - print bias',@md.fn[:pdf_p]
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:pdf_l]}")==true
-          id,file='PDF (landscape)',@md.fn[:pdf_l]
+          id,file='PDF (landscape) - screen view bias (colored links)',@md.fn[:pdf_l]
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:plain]}")==true
-        if    @md.cmd =~/a/: id,file='plaintext Unix (UTF-8) (footnotes)',@md.fn[:plain]
-        elsif @md.cmd =~/e/: id,file='plaintext Unix (UTF-8) (endnotes)',@md.fn[:plain]
-        elsif @md.cmd =~/A/: id,file='plaintext dos (UTF-8) (footnotes)',@md.fn[:plain]
-        elsif @md.cmd =~/E/: id,file='plaintext dos (UTF-8) (endnotes)',@md.fn[:plain]
+        if    @md.cmd =~/a/; id,file='plaintext Unix (UTF-8) (footnotes)',@md.fn[:plain]
+        elsif @md.cmd =~/e/; id,file='plaintext Unix (UTF-8) (endnotes)',@md.fn[:plain]
+        elsif @md.cmd =~/A/; id,file='plaintext dos (UTF-8) (footnotes)',@md.fn[:plain]
+        elsif @md.cmd =~/E/; id,file='plaintext dos (UTF-8) (endnotes)',@md.fn[:plain]
         else                id,file='plaintext (UTF-8)',@md.fn[:plain]
         end
           summarize(id,file)
@@ -223,7 +220,7 @@ module SiSU_Manifest
       end
       def source_tests
         if @md.fns =~/\._sst$/                                                  #% decide whether to extract and include requested/required documents
-          req=@md.fns.gsub(/(.+)?\._sst$/,"\\1.composite.sst") #watch strange
+          req=@md.fns.gsub(/(.+)?\._sst$/,'\1.composite.sst') #watch strange
           if FileTest.file?("#@base_path/#{req}")==true
             id,file='Markup Composite File (SiSU source)',req
             summarize_source(id,file)
@@ -233,22 +230,14 @@ module SiSU_Manifest
           id,file='Markup (SiSU source)',@md.fns
           summarize_source(id,file)
         end
-        if FileTest.file?("#@base_path/sisupod.tgz")==true
-          id,file='SiSU doc (tar gzip)','sisupod.tgz'
+        if FileTest.file?("#@base_path/sisupod.zip")==true
+          id,file='SiSU doc (zip)','sisupod.zip'
           summarize_source(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fnb}")==true and @md.fnb =~/\.kdi$/
           id,file='Kdissert (.kdi source)',@md.fnb
           summarize_source(id,file)
         end
-        #if FileTest.file?("#@base_path/#{@md.fns}.meta")==true
-        #  id,file='Markup (SiSU source)','#{@md.fns}.meta'
-        #  summarize(id,file)
-        #end
-        #if FileTest.file?("#@base_path/#{@md.fns}.tgz")==true
-        #  id,file='sisupod (tar gzip)','#{@md.fns}.tgz'
-        #  summarize(id,file)
-        #end
       end
       def metadata_tests
         if @md.dc_title
@@ -307,14 +296,6 @@ module SiSU_Manifest
           id,info=@translate.type,@md.dc_type
           metadata(id,info)
         end
-        #if @md.owner
-        #  id,info='Owner',@md.owner
-        #  metadata(id,info)
-        #end
-        #if @md.copyright
-        #  id,info='Copyright',@md.copyright
-        #  metadata(id,info)
-        #end
         if @md.dc_rights
           id,info=@translate.rights,@md.dc_rights
           metadata(id,info)
@@ -444,11 +425,11 @@ module SiSU_Manifest
         if defined? @md.lnk and @md.lnk
           @md.lnk.each do |l|
             if defined? l[:say]
-              target=if l[:url] !~/^\.(\.)?\//: 'external'
+              target=if l[:url] !~/^\.(\.)?\//; 'external'
               else                              '_top'
               end
               url,lnk=l[:url],l[:say]
-              unless url.nil? or url.empty?: links(url,lnk,target)
+              unless url.nil? or url.empty?; links(url,lnk,target)
               end
             end
           end
@@ -457,7 +438,22 @@ module SiSU_Manifest
       def check_output
         begin
           id,file='',''
+          banner=SiSU_Viz::Banner.new
+          credits=SiSU_Viz::Credits.new
           url=SiSU_Viz::Url.new
+          banner_table=if banner.home_button_only !~ /http:\/\/www\.jus\.uio\.no\/sisu/ and banner.home_button_only !~  /sisu\.home\.png/
+<<WOK
+<table summary="band" width="100%" border="0" cellpadding="3" cellspacing="0">
+<tr><td align="left" bgcolor="#ffffff">#{banner.home_button}</td><td width="80%"><p class="tiny"><a href="#@base_url/#{file}"><img border="0" height="12" width="12" src="#{url.path_image}/bullet_red.png"  alt="TOC linked" />&nbsp;#@base_url/#{file}</a></p></td><td><a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" src="#{url.path_image}/sisu.png" alt="SiSU --&gt;" /></a></td></tr>
+</table>
+WOK
+          else
+<<WOK
+<table summary="band" border="0" cellpadding="3" cellspacing="0">
+<tr><td align="left" bgcolor="#ffffff"><a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" src="#{url.path_image}/sisu.png" alt="SiSU --&gt;" /></a></td><td><p class="tiny"><a href="#@base_url/#{file}"><img border="0" height="12" width="12" src="#{url.path_image}/bullet_red.png"  alt="TOC linked" />&nbsp;#@base_url/#{file}</a></p></td></tr>
+</table>
+WOK
+          end
           @manifest[:html] <<<<WOK
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
@@ -470,12 +466,10 @@ SiSU manifest: #{@md.title}
 <meta name="sourcefile" content="#{@md.fns}" />
 <link rel="generator" href="http://www.jus.uio.no/sisu" />
 <link rel="shortcut icon" href="../_sisu/image/rb7.ico" />
-<link rel="stylesheet" href="../#{@env.style}/html.css" type="text/css" />
+<link rel="stylesheet" href="../#{@env.path.style}/html.css" type="text/css" />
 </head>
 <body bgcolor="#ffffff" text="#000000" link="#003090" lang="en" xml:lang="en">
-<table summary="band" border="0" cellpadding="3" cellspacing="0">
-<tr><td align="left" bgcolor="#ffffff"><a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" src="#{url.path_image}/sisu.png" alt="SiSU --&gt;" /></a></td><td><p class="tiny"><a href="#@base_url/#{file}"><img border="0" height="12" width="12" src="#{url.path_image}/bullet_red.png"  alt="TOC linked" />&nbsp;#@base_url/#{file}</a></p></td></tr>
-</table>
+#{banner_table}
 <h1 class="small">#{@md.dc_title}</h1>
 <table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
 WOK
@@ -520,11 +514,12 @@ WOK
           language_versions
           @manifest[:html] <<<<WOK
 </table>
+#{credits.credits}
 </body>
 </html>
 WOK
           output
-        rescue: SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
+        rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
         ensure
         end
       end
