@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: php (formating) template
 
@@ -53,16 +53,16 @@ module Format
   include SiSU_Viz
   class Paragraph_number
     def initialize(paranum)
-      @paranum=paranum[/(\d+)/im,1]
+      @paranum=paranum[/(\d+)/m,1]
     end
     def display
-      p_num_display=@paranum.gsub(/(\d+)/,%{<font size="1" color="#777777" align="right">&nbsp;\#\\1&nbsp;</font>})
+      p_num_display=@paranum.gsub(/(\d+)/,'<font size="1" color="#777777" align="right">&nbsp;#\1&nbsp;</font>')
     end
     def name
-      p_num_name=@paranum.gsub(/(\d+)/,%{<a name="\\1"></a>})
+      p_num_name=@paranum.gsub(/(\d+)/,'<a name="\1"></a>')
     end
     def goto
-      p_num_goto=@paranum.gsub(/(\d+)/,%{<a href="#\\1">})
+      p_num_goto=@paranum.gsub(/(\d+)/,'<a href="#\1">')
     end
   end
   class Head_information
@@ -81,33 +81,32 @@ module Format
       case @parablock
         when /^(?:<:i[12]>\s*)?\((i+|iv|v|vi+|ix|x|xi+)\)/
           @parablock.gsub!(/^\((i+|iv|v|vi+|ix|x|xi+)\)/,
-            %{<b>(\\1)</b>})
+            '<b>(\1)</b>')
           @parablock.gsub!(/^(<:i[12]>)\s*\((i+|iv|v|vi+|ix|x|xi+)\)/,
-            %{\\1<b>(\\2)</b>})
+            '\1<b>(\2)</b>')
         when /^(?:<:i[12]>\s*)?\(?(\d|[a-z])+\)/
           @parablock.gsub!(/^\((\d+|[a-z])+\)/,
-            %{<b>(\\1)</b>})
+            '<b>(\1)</b>')
           @parablock.gsub!(/^(<:i[12]>)\s*\((\d+|[a-z])+\)/,
-            %{\\1<b>(\\2)</b>})
+            '\1<b>(\2)</b>')
         when /^\s*\d{1,3}\.\s/
           @parablock.gsub!(/^\s*(\d+\.)/,
-            %{<b>\\1</b>})
+            '<b>\1</b>')
         when /^\s*[A-Z]\.\s/
           @parablock.gsub!(/^\s*([A-Z]\.)/,
-            %{<b>\\1</b>})
+            '<b>\1</b>')
       end
     end
     def table
       @@tablefoot=@parablock[/<!f(.+?)!>/,1]
-      @parablock.gsub!(/<!f.+?!>/,
-        %{})
-      @@tablehead=1 if @parablock =~/<!Th¡/i
+      @parablock.gsub!(/<!f.+?!>/,'')
+      @@tablehead=1 if @parablock =~/<!Th¡/
       @parablock.gsub!(/<!Th?¡.+/,
         %{#{@margin.txt_0}} +
-        %{<table width="100%">})
+        '<table width="100%">')
       if @parablock =~/<!TZ!>/
         @parablock.gsub!(/<!TZ!>/,
-          %{</table>} +
+          '</table>' +
           %{#{@margin.num}} +
           %{#{@margin.num}&nbsp;} +
           %{#{@table.close}\n} +
@@ -117,37 +116,37 @@ module Format
       if @@tablehead == 1
         if @parablock =~/¡¡/
           @parablock.gsub!(/<!¡¡(\d+?)¡/,
-            %{<tr>} +
-            %{<td width="\\1%" valign="top">} +
+            '<tr>' +
+            '<td width="\1%" valign="top">' +
             %{#{@paragraph.table}<b>})
           @parablock.gsub!(/¡¡(\d+?)¡/,
-            %{</b></td><td width="\\1%" valign="top">} +
+            '</b></td><td width="\1%" valign="top">' +
             %{#{@paragraph.table}<b>})
           @parablock.gsub!(/!>/,
-            %{</b></td></tr>})
+            '</b></td></tr>')
           @@tablehead=0 #if @parablock =~/!>/
         end
         @parablock
       else
         @parablock.gsub!(/<!¡¡(\d+?)¡/,
-          %{<tr>} +
-          %{<td width="\\1%" valign="top">} +
+          '<tr>' +
+          '<td width="\1%" valign="top">' +
           %{#{@paragraph.table}})
         @parablock.gsub!(/¡¡(\d+?)¡/,
-          %{</td><td width="\\1%" valign="top">} +
+          '</td><td width="\1%" valign="top">' +
           %{#{@paragraph.table}})
         @parablock.gsub!(/!>/,
-          %{</td></tr>})
+          '</td></tr>')
         @parablock
       end
     end
     def toc_head_copy_at
-      %{<p class="center">} +
+      '<p class="center">' +
         %{#@one} +
       %{</p>\n}
     end
     def center
-      %{<p class="center">} +
+      '<p class="center">' +
         %{#@one} +
       %{</p>\n}
     end
@@ -156,7 +155,7 @@ module Format
       %{#{@paragraph.txt}} +
       %{<b>#@one</b> } +
       %{#{@margin.num}} +
-      %{&nbsp;&nbsp;&nbsp;} +
+      '&nbsp;&nbsp;&nbsp;' +
       %{#{@table.close}\n}
     end
   end
@@ -374,13 +373,6 @@ module Format
       %{#{@table.close}\n}
     end
   end
-  #class TrioSiSU
-  #  def tocLinksGuide
-  #    %{ <a href="#@link" Target="#@three">
-  #    %{<img border="0" height="8" width="8" src="#{@url.path_png} #{@icon.doc}" alt="Section on #@linkname"> } +
-  #    %{#@linkname</a> \n}
-  #  end
-  #end
   class ParaSiSU
     def para
       %{#{@margin.txt_0}} +
@@ -537,18 +529,18 @@ module Format
       %{#{@table.close}\n}
     end
     def seg_nav_header4                                                            #segNavHeader4 |html.rb|@|#navSegLev4|
-      %{<table summary="navigation segment header 4" width=100% bgcolor="#08163f" border="0">} +
+      '<table summary="navigation segment header 4" width=100% bgcolor="#08163f" border="0">' +
       %{\n<tr>} +
       %{\n<td align="center">} +
-      %{<p><b><font size="4" color="#ffffff">} +
+      '<p><b><font size="4" color="#ffffff">' +
       %{<b>#@parablock</b>} +
       %{</font></b></p>} +
       %{#{@table.close}\n}
     end
     def seg_nav_header5                                                            # see instead |html_tune_nav.rb|@|#navSegLev5|
-      %{<center><table summary="navigation segment header 5" width="100%" } +
-        %{border="1" } +
-        %{cellpadding="12" } +
+      '<center><table summary="navigation segment header 5" width="100%" ' +
+        'border="1" ' +
+        'cellpadding="12" ' +
         %{bgcolor=#{@color.lev5}>} +
       %{\n<tr align=center>} +
       %{\n<td>} +
@@ -556,9 +548,9 @@ module Format
       %{#{@table.close}</center>\n}
     end
     def seg_nav_header6
-      %{<center><table summary="navigation segment header 6" width="100%" } +
-      %{border="1" } +
-      %{cellpadding="12" } +
+      '<center><table summary="navigation segment header 6" width="100%" ' +
+      'border="1" ' +
+      'cellpadding="12" ' +
       %{bgcolor=#{@color.lev6}>} +
       %{\n<tr align=center>} +
       %{\n<td>} +
