@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: relaxng flow/logic
 
@@ -56,7 +56,7 @@ module SiSU_relaxng
  #  Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  #  Author: Ralph Amissah
  #    http://www.jus.uio.no/sisu
- #    http://www.jus.uio.no/sisu/SiSU/download
+ #    http://www.jus.uio.no/sisu/SiSU/download.html
 
  #  Description: sisu object models in relaxNG
 
