@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: semantics
 
@@ -51,7 +51,7 @@ module Semantic
   class YamlInfoCreate
     def initialize(file='')
       @file=file
-      @sisu=Array.new
+      @sisu=[]
       @@doc[:title],@@doc[:subtitle],@@doc[:creator],@@doc[:subject],@@doc[:keywords],@@doc[:description],@@doc[:publisher],@@doc[:contributor],@@doc[:date],@@doc[:date_created],@@doc[:date_issued],@@doc[:date_available],@@doc[:date_valid],@@doc[:date_modified],@@doc[:type],@@doc[:format],@@doc[:identifier],@@doc[:source],@@doc[:language],@@doc[:coverage],@@doc[:relation],@@doc[:rights]=nil,nil,nil,nil,nil,nil,nil,nil,nil,nil,nil,nil,nil,nil,nil,nil,nil,nil,nil,nil,nil,nil
     end
     def songsheet
@@ -60,7 +60,7 @@ module Semantic
     end
     def param
       file_array=IO.readlines(@file,'')
-      SiSU_Param(file_array,@file,"a") #problem not updated watch
+      SiSU_Param(file_array,@file,'a') #problem not updated watch
     end
     def printscreen
       puts "#{@@cX.fuschia}filename:#{@@cX.off}       " + @file
@@ -85,47 +85,46 @@ module Semantic
       puts "#{@@cX.fuschia}coverage:#{@@cX.off}       " + @@doc[:coverage] if @@doc[:coverage]
       puts "#{@@cX.fuschia}relation:#{@@cX.off}       " + @@doc[:relation] if @@doc[:relation]
       puts "#{@@cX.fuschia}rights:#{@@cX.off}         " + @@doc[:rights] if @@doc[:rights]
-      #puts "#{@@cX.fuschia}copyright:#{@@cX.off}      " + @@doc[:copyright] if @@doc[:copyright]
       puts "#{@@cX.fuschia}keywords:#{@@cX.off}       " + @@doc[:keywords] if @@doc[:keywords]
       puts '-----------------------'
     end
     def yamlinfo
       uri=case @file
-      when /.+?\.[_-]?sst$/: @file.gsub(/(.+?)\.[_-]?sst$/,"http://localhost/reserved/\\1/")
+      when /.+?\.[_-]?sst$/; @file.gsub(/(.+?)\.[_-]?sst$/,'http://localhost/reserved/\1/')
       end
-      p uri
+      puts uri
       @sisu << '-'
-      @sisu << "  filename:       " + uri
-      @sisu << "  title:          " + @@doc[:title].gsub(/:/, ' - ') if @@doc[:title]
-      @sisu << "  subtitle:       " + @@doc[:subtitle] if @@doc[:subtitle]
-      @sisu << "  creator:        " + @@doc[:creator] if @@doc[:creator]
-      @sisu << "  subject:        " + @@doc[:subject] if @@doc[:subject]
-      @sisu << "  keywords:       " + @@doc[:keywords] if @@doc[:keywords]
-      @sisu << "  description:    " + @@doc[:description] if @@doc[:description]
-      @sisu << "  publisher:      " + @@doc[:publisher] if @@doc[:publisher]
-      @sisu << "  contributor:    " + @@doc[:contributor] if @@doc[:contributor]
-      @sisu << "  date:           " + @@doc[:date] if @@doc[:date]
-      @sisu << "  date_created:   " + @@doc[:date_created] if @@doc[:date_created]
-      @sisu << "  date_issued:    " + @@doc[:date_issued] if @@doc[:date_issued]
-      @sisu << "  date_available: " + @@doc[:dateavailable] if @@doc[:date_available]
-      @sisu << "  date_valid:     " + @@doc[:date_valid] if @@doc[:date_valid]
-      @sisu << "  date_modified:  " + @@doc[:date_modified] if @@doc[:date_modified]
-      @sisu << "  type:           " + @@doc[:type] if @@doc[:type]
-      @sisu << "  format:         " + @@doc[:format] if @@doc[:format]
-      @sisu << "  identifier:     " + @@doc[:identifier] if @@doc[:identifier]
-      @sisu << "  source:         " + @@doc[:source] if @@doc[:source]
-      @sisu << "  language:       " + @@doc[:language] if @@doc[:language]
-      @sisu << "  coverage:       " + @@doc[:coverage] if @@doc[:coverage]
-      @sisu << "  relation:       " + @@doc[:relation] if @@doc[:relation]
-      @sisu << "  rights:         " + @@doc[:rights] if @@doc[:rights]
-      #@sisu << "  copyright:      " + @@doc[:copyright] if @@doc[:copyright]
+      @sisu << '  filename:       ' + uri
+      @sisu << '  title:          ' + @@doc[:title].gsub(/:/, ' - ') if @@doc[:title]
+      @sisu << '  subtitle:       ' + @@doc[:subtitle] if @@doc[:subtitle]
+      @sisu << '  creator:        ' + @@doc[:creator] if @@doc[:creator]
+      @sisu << '  subject:        ' + @@doc[:subject] if @@doc[:subject]
+      @sisu << '  keywords:       ' + @@doc[:keywords] if @@doc[:keywords]
+      @sisu << '  description:    ' + @@doc[:description] if @@doc[:description]
+      @sisu << '  publisher:      ' + @@doc[:publisher] if @@doc[:publisher]
+      @sisu << '  contributor:    ' + @@doc[:contributor] if @@doc[:contributor]
+      @sisu << '  date:           ' + @@doc[:date] if @@doc[:date]
+      @sisu << '  date_created:   ' + @@doc[:date_created] if @@doc[:date_created]
+      @sisu << '  date_issued:    ' + @@doc[:date_issued] if @@doc[:date_issued]
+      @sisu << '  date_available: ' + @@doc[:dateavailable] if @@doc[:date_available]
+      @sisu << '  date_valid:     ' + @@doc[:date_valid] if @@doc[:date_valid]
+      @sisu << '  date_modified:  ' + @@doc[:date_modified] if @@doc[:date_modified]
+      @sisu << '  type:           ' + @@doc[:type] if @@doc[:type]
+      @sisu << '  format:         ' + @@doc[:format] if @@doc[:format]
+      @sisu << '  identifier:     ' + @@doc[:identifier] if @@doc[:identifier]
+      @sisu << '  source:         ' + @@doc[:source] if @@doc[:source]
+      @sisu << '  language:       ' + @@doc[:language] if @@doc[:language]
+      @sisu << '  coverage:       ' + @@doc[:coverage] if @@doc[:coverage]
+      @sisu << '  relation:       ' + @@doc[:relation] if @@doc[:relation]
+      @sisu << '  rights:         ' + @@doc[:rights] if @@doc[:rights]
+      #@sisu << '  copyright:      ' + @@doc[:copyright] if @@doc[:copyright]
       @sisu.each {|para| @@filename_semantic.puts para}
     end
   end
   class Yaml_info_read
     def initialize #(file='')
       @pwd=Dir.pwd
-      @sisu=Array.new
+      @sisu=[]
     end
     def loadfile
       if FileTest.file?("#@pwd/semantic.yaml") 
@@ -167,8 +166,8 @@ module Semantic
       rss_nav
       debris
     end
-    def rss(match=//, feedtitle='')
-      @sisu=Array.new
+    def rss(match=//,feedtitle='')
+      @sisu=[]
       @sisu <<  %{<rss version="2.0">\n-\n  <channel><title>#{feedtitle}</title>
 <link>http://www.jus.uio.no/lm/</link>
 <description>Semantic Information Structuring Unit</description>
@@ -177,8 +176,7 @@ module Semantic
 }
       @yaml.each do |y| 
         if y['title'] and ((y['subject'] and "#{y['subject']}"[match]) or (y['keywords'] and "#{y['keywords']}"[match]))
-          #p y['keywords']
-          p y['subject']
+          puts y['subject']
           @sisu <<  %{-
   <item>
   <title>#{y['title']}</title>
@@ -221,23 +219,23 @@ module Semantic
       #@sisu.each {|para| @@rss.puts para} #KEEP does all
       if "united nations"[match]
         @sisu.each {|para| @@rss_un.puts para}
-        @sisu=Array.new
+        @sisu=[]
       end
       if "unidroit"[match]
         @sisu.each {|para| @@rss_unidroit.puts para}
-        @sisu=Array.new
+        @sisu=[]
       end
       if "hcpil"[match]
         @sisu.each {|para| @@rss_hcpil.puts para}
-        @sisu=Array.new
+        @sisu=[]
       end
       if "contract"[match]
         @sisu.each {|para| @@rss_contracts.puts para}
-        @sisu=Array.new
+        @sisu=[]
       end
       if "navigate"[match]
         @sisu.each {|para| @@rss_nav.puts para}
-        @sisu=Array.new
+        @sisu=[]
       end
     end
     def rss_un
@@ -293,14 +291,14 @@ module Semantic
       @sisu.each {|para| @@rss.puts para}
     end
     def debris
-      outputdir=SiSU_Env::Info_dir.new.feed
+      outputdir=SiSU_Env::Info_env.new.path.feed
       x=Dir.new(outputdir).entries
       x.each do |y|
         #unless FileTest.file?("#{outputdir}/#{y}") and File.size?("#{outputdir}/#{y}") == 0
         if File.size("#{outputdir}/#{y}") == 0
           #File.unlink("#{outputdir}/#{y}")
-          p "#{outputdir}/#{y}"
-          p File.size("#{outputdir}/#{y}")
+          puts "#{outputdir}/#{y}"
+          puts File.size("#{outputdir}/#{y}")
         end
       end
     end
@@ -308,7 +306,6 @@ module Semantic
   class RDF < Yaml_info_read
     def songsheet
       loadfile
-      #printscreen
       rdf
       rdf_un
       rdf_unidroit
@@ -340,9 +337,9 @@ require SiSU_lib + '/sysenv'
 include SiSU_Param
 include SiSU_Env
 include SiSU_Viz
-outputdir=SiSU_Env::Info_dir.new.feed
+outputdir=SiSU_Env::Info_env.new.path.feed
 pwd=Dir.pwd
-@argv=Array.new
+@argv=[]
 argv=$*
 p argv
 my_make=SiSU_Env::Create_file.new('','')
