@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: texinfo formatting template
 
@@ -61,19 +61,19 @@ module TexInfoFormat
       @para=@one=data
       @md=md
       @url=SiSU_Viz::Url.new
-      @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
+      @@dp ||=SiSU_Env::Info_env.new.digest.pattern
     end
     def head
       t=Time.now
       year = t.year
       filename=%{#{@md.fns}}[/(.+?)\.\w\w\d\d$/,1]
       title=Texinfo.new(@md.title).spec_char
-      title=title.gsub(/<(br|p|i)>|<\/\s*(br|p|i)>|<(br|p)\s*\/>/i," #{@@tex_backslash*2} ")
+      title=title.gsub(/<(br|p|i)>|<\/\s*(br|p|i)>|<(br|p)\s*\/>/," #{@@tex_backslash*2} ")
       title.gsub!(/\$/,"\\$")
       title.gsub!(/[,]\s*/,' - ')
       if @md.subtitle
         subtitle=Texinfo.new(@md.subtitle).spec_char
-        subtitle=subtitle.gsub(/<(br|p|i)>|<\/\s*(br|p|i)>|<(br|p)\s*\/>/i," #{@@tex_backslash*2} ")
+        subtitle=subtitle.gsub(/<(br|p|i)>|<\/\s*(br|p|i)>|<(br|p)\s*\/>/," #{@@tex_backslash*2} ")
         subtitle.gsub!(/\$/,"\\$")
         subtitle.gsub!(/[,]\s*/,' - ')
         subtitle="@subtitle @value{VERSION}, @value{UPDATED}\n" #bugwatch
@@ -138,7 +138,7 @@ WOK
     end
     def topnode
       @one=Texinfo.new(@one).spec_char
-      @one=@one.gsub(/<(br|p|i)>|<\/\s*(br|p|i)>|<(br|p)\s*\/>/i," #{@@tex_backslash*2} ")
+      @one=@one.gsub(/<(br|p|i)>|<\/\s*(br|p|i)>|<(br|p)\s*\/>/," #{@@tex_backslash*2} ")
       @one.gsub!(/\$/,"\\$")
       @one.gsub!(/[,]\s*/,' - ')
       "@c {{{ 4\n" +
@@ -224,7 +224,7 @@ WOK
       "@bye"
     end
     def menu
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,"~[\\1]")
+      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,'~[\1]')
       @para.gsub!(/\s*[,:]\s*/,' - ')
       @para.gsub!(/<:#>/,'')
       @para.strip!
@@ -232,7 +232,7 @@ WOK
     end
     def level1
       @para.gsub!(/[1]\\+~/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,"~[\\1]")
+      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,'~[\1]')
       @para.gsub!(/\s*[,:]\s*/,' - ')
       @para.gsub!(/<:#>/,'')
       @para.strip!
@@ -241,7 +241,7 @@ WOK
     end
     def level2
       @para.gsub!(/[2]\\+~/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,"~[\\1]")
+      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,'~[\1]')
       @para.gsub!(/\s*[,:]\s*/,' - ')
       @para.gsub!(/<:#>/,'')
       @para.strip!
@@ -250,7 +250,7 @@ WOK
     end
     def level3
       @para.gsub!(/[3]\\+\~/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,"~[\\1]")
+      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,'~[\1]')
       @para.gsub!(/\s*[,:]\s*/,' - ')
       @para.gsub!(/<:#>/,'')
       @para.strip!
@@ -259,7 +259,7 @@ WOK
     end
     def level4
       @para.gsub!(/[4]\\+~\S+/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,"~[\\1]")
+      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,'~[\1]')
       @para.gsub!(/\s*[,:]\s*/,' - ')
       @para.gsub!(/<:#>/,'')
       @para.strip!
@@ -267,8 +267,8 @@ WOK
       @para.gsub!(/.+/,"#{para}")
     end
     def level5
-      @para.gsub!(/[5]\\+~\S+/, '')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,"~[\\1]")
+      @para.gsub!(/[5]\\+~\S+/,'')
+      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,'~[\1]')
       @para.gsub!(/\s*[,:]\s*/,' - ')
       @para.gsub!(/<:#>/,'')
       @para.strip!
@@ -277,7 +277,7 @@ WOK
     end
     def level6
       @para.gsub!(/[6]\\+~\S+/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,"~[\\1]")
+      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,'~[\1]')
       @para.gsub!(/\s*[,:]\s*/,' - ')
       @para.gsub!(/<:#>/,'')
       @para.strip!
@@ -287,7 +287,7 @@ WOK
     def submenu
       @para=@para.join("\n")
       @para.gsub!(/[5]\\+~\S+/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,"~[\\1]")
+      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,'~[\1]')
       @para.gsub!(/\s*[,]\s*/,' - ')
       @para.gsub!(/<:#>/,'')
       @para.strip!
@@ -297,7 +297,7 @@ WOK
     def subsubmenu
       @para=@para.join("\n")
       @para.gsub!(/[6]\\+~\S+/,'')
-      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,"~[\\1]")
+      @para.gsub!(/<\\~(\d+);\w\d+;\w\d+><#{@@dp}:#{@@dp}>/,'~[\1]')
       @para.gsub!(/\s*[,]\s*/,' - ')
       @para.gsub!(/<:#>/,'')
       @para.strip!
@@ -305,22 +305,22 @@ WOK
       @para.gsub!(/.+/m,"#{para}")
     end
     def indent1
-      @para.gsub!(/<:i1>(.*)/i,"\\1")
+      @para.gsub!(/<:i1>(.*)/,'\1')
     end
     def indent2
-      @para.gsub!(/<:i2>(.*)/i,"\\1")
+      @para.gsub!(/<:i2>(.*)/,'\1')
     end
     def spec_char # special characters
-      @para.gsub!(/<EOF>/i,"")
+      @para.gsub!(/<EOF>/i,'')
       @para.gsub!(/@/i,'@@')
-      @para.gsub!(/&(lt|#060);/i,'\<&nbsp;')
-      @para.gsub!(/&(gt|#062);/i,'&nbsp;\>')
-      @para.gsub!(/&#123;/i,'\{&nbsp;')
-      @para.gsub!(/&#125;/i,'\}&nbsp;')
+      @para.gsub!(/&(lt|#060);/,'\<&nbsp;')
+      @para.gsub!(/&(gt|#062);/,'&nbsp;\>')
+      @para.gsub!(/&#123;/,'\{&nbsp;')
+      @para.gsub!(/&#125;/,'\}&nbsp;')
       @para.gsub!(/&#(126|152);/i,'~&nbsp;')
-      @para.gsub!(/<sup><font face=symbol>&atild;<\/font><\/sup>/i," ")
+      @para.gsub!(/<sup><font face=symbol>&atild;<\/font><\/sup>/,' ')
       @para.gsub!(/\\/,'\\backslash ')
-      @para.gsub!(/<:pb>/i,'\\newpage')
+      @para.gsub!(/<:pb>/,'\\newpage')
       @para.gsub!(/\\backslash copyright/,'\\copyright ')
       @para.gsub!(/\^/,'\\wedge ')
       @para.gsub!(/(\$)/,"\\$")
@@ -331,9 +331,9 @@ WOK
       end
       @para.gsub!(/\{/,"\\{")
       @para.gsub!(/\}/,"\\}")
-        @para.gsub!(/&nbsp;&nbsp;/i,' ')  # ~ character for hardspace
-        @para.gsub!(/&nbsp;/i,' ')        # ~ character for hardspace
-      @para.gsub!(/&(\S+?);/i,'')
+        @para.gsub!(/&nbsp;&nbsp;/,' ')  # ~ character for hardspace
+        @para.gsub!(/&nbsp;/,' ')        # ~ character for hardspace
+      @para.gsub!(/&(\S+?);/,'')
       @para.gsub!(/(\s+&\s+)/,' and ')
       @para.gsub!(/(\&)/,"\\&")
       @para.gsub!(/§/i,'\S')
@@ -349,25 +349,25 @@ WOK
       @para.gsub!(/<\/a>/i,' ')
       @para.gsub!(/<:ee>/i,'')
       @para.gsub!(/<!>/i,' ')
-      @para.gsub!(/<b>(.+?)<\/b>/i,"\*\\1\*")
-      @para.gsub!(/<i>(.+?)<\/i>/i,"\/\\1\/")
-      @para.gsub!(/<u>(.+?)<\/u>/i,"\_\\1\_")
-      @para.gsub!(/"(.+?)"/i,"`\\1'")                                        # open & close "
-      @para.gsub!(/\s+"/i," `")                                              # open "
-      @para.gsub!(/^([1-6-]\\+(?:~\S+)?|<.+?>)?\s*"/i,"\\1`")       # open "
-      @para.gsub!(/"(\s|\.|,|:|;)/i,"'\\1")                                  # close "
-      @para.gsub!(/"([1-6-]\\+(?:~\S+)?|<.+?>)?\s*$/i,"'\\1")       # close "
-      @para.gsub!(/"(\.|,)/i,"'")                                            # close "
-      @para.gsub!(/\s+'/i," `")                                              # open '
-      @para.gsub!(/^([1-6-]\\+(?:~\S+)?|<.+?>)?\s*'/i,"\\1`")       # open '
+      @para.gsub!(/<b>(.+?)<\/b>/,'\*\1\*')
+      @para.gsub!(/<i>(.+?)<\/i>/,'\/\1\/')
+      @para.gsub!(/<u>(.+?)<\/u>/,'\_\1\_')
+      @para.gsub!(/"(.+?)"/,"`\\1'")                                        # open & close "
+      @para.gsub!(/\s+"/," `")                                              # open "
+      @para.gsub!(/^([1-6-]\\+(?:~\S+)?|<.+?>)?\s*"/,"\\1`")       # open "
+      @para.gsub!(/"(\s|\.|,|:|;)/,"'\\1")                                  # close "
+      @para.gsub!(/"([1-6-]\\+(?:~\S+)?|<.+?>)?\s*$/,"'\\1")       # close "
+      @para.gsub!(/"(\.|,)/,"'")                                            # close "
+      @para.gsub!(/\s+'/," `")                                              # open '
+      @para.gsub!(/^([1-6-]\\+(?:~\S+)?|<.+?>)?\s*'/,"\\1`")       # open '
       #if @para=~/#{@@tex_1}/
       #end
       #@para.gsub!(/^([1-6-](?:#{@@tex_2}|#{@@tex_1})(?:\\~\S+)?|<.+?>)?\s*"/i,"\\1`")       # open "
       #@para.gsub!(/"([1-6-](?:#{@@tex_2}|#{@@tex_1})(?:\\~\S+)?|<.+?>)?\s*$/i,"'\\1")       # close "
       #@para.gsub!(/^([1-6-](?:#{@@tex_2}|#{@@tex_1})(?:\\~\S+)?|<.+?>)?\s*'/i,"\\1`")       # open '
-      @para.gsub!(/(<font.*?>|<\/font>)/i,"")
-      @para.gsub!(/\s*<sup>(\S+?)<\/sup>/i,"^\\1")
-      @para.gsub!(/(<sup>|<\/sup>)/i,'')
+      @para.gsub!(/(<font.*?>|<\/font>)/,'')
+      @para.gsub!(/\s*<sup>(\S+?)<\/sup>/,'^\1')
+      @para.gsub!(/(<sup>|<\/sup>)/,'')
       @para
     end
     def longtable
@@ -378,7 +378,7 @@ WOK
         @@tableheader=1 if @para =~ /<!Th/i
         @w=cols_width.split(/;\s+/)
         @@number_of_cols=no_of_cols
-        @colW=Array.new
+        @colW=[]
         @colW << '{'
         @w.each  do |x|
           col_w=x.gsub(/.+/,'l\|') #unless x.nil?
@@ -424,7 +424,7 @@ WOK
       if @para[/<!Th?¡\s+c(\d+);(.+?)!>/i]
         no_of_cols,cols_width=$1,$2
         @w=cols_width.split(/;\s+/)
-        @colW=Array.new
+        @colW=[]
         @w.each  do |x|
           col_w=((x.to_i*12)/100.00).to_s #unless x.nil?
           @colW << "p{#{col_w}cm}" if col_w
@@ -457,32 +457,32 @@ WOK
       @para
     end
     def graphics
-      dir=SiSU_Env::Info_dir.new(@md.fns)
+      dir=SiSU_Env::Info_env.new(@md.fns)
       @para.gsub!(/<::\s+(\S+?)\s+>/i, #watch
-        "\\includegraphics*[width=11pt]{#{dir.image_source_tex}/c_\\1.png}")
+        "\\includegraphics*[width=11pt]{#{dir.path.image_source_tex}/c_\\1.png}")
     end
     def image
-      dir=SiSU_Env::Info_dir.new(@md.fns)
+      dir=SiSU_Env::Info_env.new(@md.fns)
       width="100"
       width=@para[/<:image.+?width=``(\d+)''.+?>/im,1]
       width=width.to_i*0.4
       @para.gsub!(/<:image\s+((?:https?|ftp)\S+)\s+(\S+)\s+.+\s+?>/i,
-        "\\href{\\1}{\\includegraphics*[width=#{width}pt]{#{dir.image_source_tex}/\\2}}")
+        "\\href{\\1}{\\includegraphics*[width=#{width}pt]{#{dir.path.image_source_tex}/\\2}}")
       @para.gsub!(/<:image\s+(\S+)\s+.+\s+?>/i,
-        "\\includegraphics*[width=#{width}pt]{#{dir.image_source_tex}/\\1}")
+        "\\includegraphics*[width=#{width}pt]{#{dir.path.image_source_tex}/\\1}")
     end
     def png
       # very messy clean up ! - work area, testing
       z=@para[/\\\{(.+?)\}(?:image|png)/,1] # match operator for z \\ fragile !
       image,w,x,y=z.scan(/\S+/)
       image.gsub!(/\\/,'')
-      @para.gsub!(/\\\{\S+\.(png|jpg).+?\}(image|png)/,"<image #{image} not available>")  # fragile match operator\\ fragile ! 
+      @para.gsub!(/\\\{\S+\.(png|jpg|gif).+?\}(image|png)/,"<image #{image} not available>")  # fragile match operator\\ fragile ! 
     end
     def http
       # very messy clean up ! - work area, testing
       z=@para[/\\\{(.+?)\}(?:https?|ftp):\/\//,1] # match operator for z \\ fragile !
       url=@para[/((?:https?|ftp):\S+)/im,1]
-      if @para =~/\.(png|jpg)/
+      if @para =~/\.(png|jpg|gif)/
         image,w,x,y=z.scan(/\S+/)
         image.gsub!(/\\/,'')
         width=200
@@ -493,9 +493,9 @@ WOK
         caption="{\\\\\\\ \n\\begin{scriptsize}#{c}\\end{scriptsize}&}" if c
       end
       if image
-        dir=SiSU_Env::Info_dir.new(@md.fns)
-        @para.gsub!(/\{\S+\.(png|jpg).+?\}(?:https?|ftp):\/\/\S+/, # fragile match operator\\ fragile ! 
-          "\n\\href{#{url}}{\\includegraphics*[width=#{width}pt]{#{dir.image_source_tex}/#{image}}}#{caption}")
+        dir=SiSU_Env::Info_env.new(@md.fns)
+        @para.gsub!(/\{\S+\.(png|jpg|gif).+?\}(?:https?|ftp):\/\/\S+/, # fragile match operator\\ fragile ! 
+          "\n\\href{#{url}}{\\includegraphics*[width=#{width}pt]{#{dir.path.image_source_tex}/#{image}}}#{caption}")
       else
         link=z[/(.+?)\\/im,1]
         @para.gsub!(/\{.+?\}(?:https?|ftp):\/\/\S+/,"\n\\noindent\\href{#{url}}{#{link}}")  # fragile match operator\\ fragile ! 
