@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: xhtml output logic, flow
 
@@ -55,7 +55,7 @@ module SiSU_XHTML #XML_SAX derivative
   include SiSU_Viz
   require SiSU_lib + '/sysenv'
   include SiSU_Env
-  require SiSU_lib + '/common_xml'
+  require SiSU_lib + '/shared_xml'
   require SiSU_lib + '/xml_format'
   include SiSU_XML_format
   include SiSU_XML_character
@@ -72,21 +72,19 @@ module SiSU_XHTML #XML_SAX derivative
     def read
       begin
         @md=SiSU_Param::Parameters.new(@opt).get
-        @env=SiSU_Env::Info_dir.new(@opt.fns)
-        path=SiSU_Env::Info_dir.new(@opt.fns).tell_output_path
-        loc=SiSU_Env::Info_dir.new(@opt.fns).tell_output_location
-        tool=if @opt.cmd =~/[MV]/: "#{@env.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:xhtml]}\n\t#{@env.xml_viewer} #{path}/#{@md.fnb}/#{@md.fn[:xhtml]}"
-        elsif @opt.cmd =~/v/: "#{@env.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:xhtml]}"
+        @env=SiSU_Env::Info_env.new(@opt.fns)
+        path=@env.path.output_tell
+        loc=@env.url.output_tell
+        tool=if @opt.cmd =~/[MV]/; "#{@env.program.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:xhtml]}\n\t#{@env.program.xml_viewer} #{path}/#{@md.fnb}/#{@md.fn[:xhtml]}"
+        elsif @opt.cmd =~/v/; "#{@env.program.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:xhtml]}"
         else ''
         end
-        tell=SiSU_Screen::Ansi.new(@opt.cmd,'invert','XHTML',tool)
-        tell.colorize unless @opt.cmd =~/q/
-        tell=SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.tell_output_path}/#{@md.fnb}/#{@md.fn[:xhtml]}")
-        tell.flow if @opt.cmd =~/[MV]/
+        SiSU_Screen::Ansi.new(@opt.cmd,'invert','XHTML',tool).colorize unless @opt.cmd =~/q/
+        SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.path.output_tell}/#{@md.fnb}/#{@md.fn[:xhtml]}").flow if @opt.cmd =~/[MV]/
         my_make=SiSU_Env::Create_file.new(@opt.cmd,@opt.fns)
         @metaverse_array=SiSU_Metaverse::Source.new(@opt).get # metaverse file drawn here
         SiSU_XHTML::Source::Songsheet.new(@md,@metaverse_array,@env).songsheet
-      rescue: SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
         #file closed in songsheet
       end
@@ -98,57 +96,64 @@ module SiSU_XHTML #XML_SAX derivative
       def songsheet
         begin
           SiSU_XHTML::Source::Scroll.new(@md,@data).songsheet
-          SiSU_XHTML::Source::Tidy.new(@md,@env).xml if @md.cmd =~/[VM]/i # test wellformedness, comment out when not in use
+          SiSU_XHTML::Source::Tidy.new(@md,@env).xml if @md.cmd =~/[vVM]/ # test wellformedness, comment out when not in use
           SiSU_Rexml::Rexml.new(@md,@md.fn[:xhtml]).xml if @md.cmd =~/M/ # test rexml parsing, comment out when not in use #debug
-        rescue: SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
+        rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
         ensure
         end
       end
     end
     class Scroll
-      @@xml=Hash.new
-      @@xml[:body],@@xml[:sisu],@@xml[:open],@@xml[:close],@@xml[:head]=Array.new,Array.new,Array.new,Array.new,Array.new
-      require SiSU_lib + '/common_text'
+      @@xml={ :body=>[],:sisu=>[],:open=>[],:close=>[],:head=>[] }
+      require SiSU_lib + '/shared_txt'
       require SiSU_lib + '/css'
       include SiSU_text_utils
       @@dp=nil
       def initialize(md=nil,data='')
         @md,@data=md,data
         @margin=SiSU_Viz::Margin.new
-        @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
+        @@dp ||=SiSU_Env::Info_env.new.digest.pattern
         @regx=/^(?:(?:<:p[nb]>\s*)?\d~(?:(\S+))?\s+)?(.+?)\s*<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>$/
         @tab="\t"
-        @env=SiSU_Env::Info_dir.new(@md.fns)
+        @env=SiSU_Env::Info_env.new(@md.fns)
         @char_enc=SiSU_XML_character::Encode.new
         @sys=SiSU_Env::System_call.new
       end
       def songsheet
-        Scroll.new(@md,@data).pre
-        Scroll.new(@md,@data).markup
-        Scroll.new(@md,@data).post
-        Scroll.new(@md,@data).publish
+        pre
+        markup
+        post
+        publish
       end
     protected
       def embedded_endntoes(para='')
         para.gsub!(/~\{(\d+)\s+(.+?)\s*<#{@@dp}>\}~/, 
-          "<endnote><number>\\1</number><note>\\2</note></endnote> ")
+          '<endnote><number>\1</number><note>\2</note></endnote> ')
+        para.gsub!(/~\[([*+]\d+)\s+(.+?)\s*<#{@@dp}>\]~/, 
+          '<endnote><symbol>\1</symbol><note>\2</note></endnote> ')
         para.gsub!(/~\{([*+]+)\s+(.+?)\s*<#{@@dp}>\}~/, 
-          "<endnote><asterisk>\\1</asterisk><note>\\2</note></endnote> ")
+          '<endnote><symbol>\1</symbol><note>\2</note></endnote> ')
       end
       def extract_endnotes(para='')
-        notes=para.scan(/~\{([\d*+]+\s+.+?)\s*<#{@@dp}>\}~/)
+        notes=para.scan(/~[{\[]([\d*+]+\s+.+?)\s*<#{@@dp}>[}\]]~/)
         notes.each do |e| 
           s=e.to_s
-          util=SiSU_text_utils::Paragraph.new(s,70)
+          util=SiSU_text_utils::Wrap.new(s,70)
           wrap=util.line_wrap
           wrap.gsub!(/^(\d+)\s+(.+?)\s*\Z/m, <<WOK
 #{@tab*1}<endnote notenumber="\\1">
 #{@tab*2}\\1. \\2
 #{@tab*1}</endnote>
 WOK
+) 
+          wrap.gsub!(/^([*+]\d+)\s+(.+?)\s*\Z/m, <<WOK
+#{@tab*1}<endnote symbol="\\1">
+#{@tab*2}\\1 \\2
+#{@tab*1}</endnote>
+WOK
 ) 
           wrap.gsub!(/^([*+]+)\s+(.+?)\s*\Z/m, <<WOK
-#{@tab*1}<endnote asterisk="\\1.length">
+#{@tab*1}<endnote symbol="\\1.length">
 #{@tab*2}\\1 \\2
 #{@tab*1}</endnote>
 WOK
@@ -163,21 +168,18 @@ WOK
           @endnotes << wrap
         end
       end
-      def xml_head_dc(meta='',verse='')
-        verse.gsub!(/<br(?: \/)?>/,'')
-        verse.gsub!(/ & /,' and ')
-        @@xml[:head] <<<<WOK
-#{@tab}<dc class="#{meta}">
-#{@tab*2}#{verse}
-#{@tab}</dc>
-WOK
-      end
-      def xml_head(meta='',verse='')
-        @@xml[:head] <<<<WOK
-#{@tab}<#{meta}>
-#{@tab*2}#{verse}
-#{@tab}</#{meta}>
+      def xml_head(meta)
+        txt=meta.text
+        txt.gsub!(/<br(?: \/)?>/,'')
+        txt.gsub!(/ & /,' and ')
+        @@xml[:head] <<= if meta.type == 'meta'
+          <<WOK
+#{@tab}<#{meta.el} class="#{meta.attrib}">
+#{@tab*2}#{txt}
+#{@tab}</#{meta.el}>
 WOK
+        else ''
+        end
       end
       def xml_structure_ee(para='',lv='',ocn='',hname='') #embedded endnotes
         lv=lv.to_i
@@ -187,12 +189,12 @@ WOK
         embedded_endnotes(para)
         if para[@regx]
           paragraph="#{para[@regx,2]}"
-          util=SiSU_text_utils::Paragraph.new(paragraph,70)
+          util=SiSU_text_utils::Wrap.new(paragraph,70)
           wrapped=util.line_wrap
         end
         @@xml[:body] << "#{@tab*0}<object>" << "\n" if para[@regx] 
         @@xml[:body] << "#{@tab*1}<ocn>#{para[@regx,3]}</ocn>" << "\n" if para[@regx,3]
-        @@xml[:body] << if lv: %{#{@tab*1}<text class="h#{lv}">#{wrapped}</text>\n} << "\n" 
+        @@xml[:body] << if lv; %{#{@tab*1}<text class="h#{lv}">#{wrapped}</text>\n} << "\n" 
         else                   %{#{@tab*1}<text class="norm">#{wrapped}</text>\n} # main text, contents, body KEEP
         end
         ##@@xml[:body] << "#{@tab*1}<text>#{para[@regx,2]}</text>\n" if para[@regx,2] # old unwrapped main text, contents, body KEEP
@@ -205,13 +207,13 @@ WOK
         lv=nil if lv == 0
         extract_endnotes(para)
         #puts @endnotes
-        para.gsub!(/~\{([\d*+]+)\s+(?:.+?)\s*<#{@@dp}>\}~/,"<en>\\1</en>")
+        para.gsub!(/~[{\[]([\d*+]+)\s+(?:.+?)\s*<#{@@dp}>[}\]]~/,'<en>\1</en>') #footnote/endnote clean
         if para[@regx]
           paragraph="#{para[@regx,2]}"
-          util=SiSU_text_utils::Paragraph.new(paragraph,70)
+          util=SiSU_text_utils::Wrap.new(paragraph,70)
           wrapped=util.line_wrap
         end
-        @@xml[:body] << if para[@regx,3]: %{#{@tab*0}<object id="#{para[@regx,3]}">} << "\n" 
+        @@xml[:body] << if para[@regx,3]; %{#{@tab*0}<object id="#{para[@regx,3]}">} << "\n" 
         else                              "#{@tab*0}<object>" << "\n" if para[@regx] 
         end
         #@@xml[:body] << "#{@tab*0}<object>" << "\n" if para[@regx] 
@@ -223,7 +225,7 @@ WOK
         @@xml[:body] << "#{@tab*1}<ocn>#{para[@regx,3]}</ocn>" << "\n" if para[@regx,3]
         ##@@xml[:body] << "#{@tab*1}<text>#{para[@regx,2]}</text>\n" if para[@regx,2] # old unwrapped main text, contents, body KEEP
         @@xml[:body] << "#{@tab*0}</object>" << "\n" if para[@regx]
-        @endnotes=Array.new
+        @endnotes=[]
       end
       def group_structure(para='',ocn='')
         para.gsub!(/<:group(?:-end)?>/,'')
@@ -236,11 +238,11 @@ WOK
         @@xml[:body] << "#{@tab*0}</object>" << "\n"
       end
       def poem_structure(para='',ocn='')
-        para.gsub!(/<:poem(?:-end)?>/,'')
+        para.gsub!(/<:verse(?:-end)?>/,'')
         para.strip!
         @@xml[:body] << %{#{@tab*0}<object id="#{ocn}">} << "\n"
         @@xml[:body] << %{#{@tab*1}<ocn>#{ocn}</ocn>} << "\n"
-        @@xml[:body] << %{#{@tab*1}<text class="poem">#{@tab*1}\n}
+        @@xml[:body] << %{#{@tab*1}<text class="verse">#{@tab*1}\n}
         @@xml[:body] << %{#{@tab*2}#{para}#{@tab*1}\n}
         @@xml[:body] << %{#{@tab*1}</text>\n}
         @@xml[:body] << "#{@tab*0}</object>" << "\n"
@@ -259,7 +261,7 @@ WOK
         @@xml[:body] << %{#{@tab*0}<object id="#{ocn}">} << "\n" #if para[@regx] 
         @@xml[:body] << %{#{@tab*1}#{table}\n#{@tab*1}\n} # unless lv  # main text, contents, body KEEP
         @@xml[:body] << "#{@tab*0}</object>" << "\n" #if para[@regx]
-        @endnotes=Array.new
+        @endnotes=[]
       end
       def tidywords(wordlist)
         wordlist.each do |x|
@@ -268,31 +270,28 @@ WOK
       end
       def markup
         data=@data
-        dir=SiSU_Env::Info_dir.new(@md.fns)
-        @endnotes=Array.new
+        dir=SiSU_Env::Info_env.new(@md.fns)
+        @endnotes=[]
         @rcdc=false
-        @level=Array.new
-        @cont=Array.new 
-        @copen=Array.new
-        @xml_contents_close=Array.new
+        @level,@cont,@copen,@xml_contents_close=[],[],[],[]
         (0..6).each { |x| @cont[x]=@level[x]=false } 
         (4..6).each { |x| @xml_contents_close[x]='' } 
         data.each do |para|
           para.gsub!(/<:pb>\s*/,'')
           para.gsub!(/<[-~]#>/,'')
           para.gsub!(/<0;\w\d+;[um]\d+><#{@@dp}:#{@@dp}>/,'')
-          para.gsub!(/\{(\S+?\.(?:png|jpg)) .+?\}(?:(?:https?|ftp):\/\/\S+|image)/, 
-            "<image.path>#{dir.url_images_local}\/\\1</image.path>")
+          para.gsub!(/\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|ftp):\/\/\S+|image)/, 
+            "<image.path>#{dir.url.images_local}\/\\1</image.path>")
           para.gsub!(/&nbsp;/,' ')
           wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
           #wordlist=para.scan(/\S+/)
           para=tidywords(wordlist).join(' ').strip
           @char_enc.utf8(para) if @sys.locale =~/utf-?8/i #% utf8
           if para =~/^0~(\S+)\s+(.+?)$/ # for headers
-            dc=SiSU_scan::Header_scan.new(@md,para).dublin
-            if dc: xml_head_dc(dc[0],dc[1])
-	    end
-	  end
+            d_meta=SiSU_text_utils::Header_scan.new(@md,para).meta
+            if d_meta; xml_head(d_meta)
+	          end
+	        end
           @rcdc=true if @rcdc==false and (para =~/~metadata/ or para =~/1~\s+Document Information/)
           if para !~/(^0~|<ENDNOTES>|<EOF>)/ 
             if para =~/.+?<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>.*/
@@ -346,7 +345,7 @@ WOK
                 else
                   matched=/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>$/mi.match(para)
                   stamp,ocn=matched[0],matched[1]
-                  if para =~ /<:poem>/
+                  if para =~ /<:verse>/
                     para.gsub!(/#{stamp}/,'')
                     poem_structure(para,ocn)
                   elsif para =~ /<:group>/
@@ -357,7 +356,7 @@ WOK
                     para.gsub!(/>/,'&gt;')
                     para.gsub!(/#{stamp}/,'')
                     code_structure(para,ocn)
-                  elsif para =~/<!Th?.+/i # tables come as single block #work area 2005w13
+                  elsif para =~/<!Th?.+/ # tables come as single block #work area 2005w13
                     table=SiSU_Tables::Table_xml.new(para,ocn)
                     para=table.table_split
                     table_structure(para,ocn)
@@ -377,7 +376,7 @@ WOK
                 format_scroll=Format_scroll.new(@md,'<br /><a name="owner.details">Owner Details</a>')
                 @@xml[:owner_details]=format_scroll.bold_para
                 para=''
-              elsif para =~/(.*)<:#>(.*)/i
+              elsif para =~/(.*)<:#>(.*)/
                 one,two=$1,$2
                 format_text=Format_text_object.new(one,two)
                 para=format_text.seg_no_paranum
@@ -399,8 +398,8 @@ WOK
               if para !~/#{@margin.txt_0}|#{@margin.txt_1}|#{@margin.txt_2}/
                 # i don't get the condition for no paranum
               end
-              if para =~/<:center>/i
-                one,two=/(.*)<:center>(.*)/i.match(para)[1,2]
+              if para =~/<:center>/
+                one,two=/(.*)<:center>(.*)/.match(para)[1,2]
                 format_text=Format_text_object.new(one,two)
                 para=format_text.center
               end
@@ -422,15 +421,14 @@ WOK
       end
       def pre
         rdf=SiSU_XML_tags::RDF.new(@md)
-        dir=SiSU_Env::Info_dir.new
+        dir=SiSU_Env::Info_env.new
         #<?xml version="1.0"?>
         #<?xml version="1.0" encoding="UTF-8" standalone="no"?>
         #<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>
         #<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
         #<?xml version="1.0" encoding="UTF-8" standalone="no"?>
         #<?xml version="1.0" encoding="UTF-16" standalone="no"?>
-        @@xml[:head]=Array.new #added
-        @@xml[:body]=Array.new #added
+        @@xml[:head],@@xml[:body]=[],[] #added
         css=SiSU_Env::CSS_select.new(@md).xhtml
         encoding=if @sys.locale =~/utf-?8/i #% utf8
           '<?xml version="1.0" encoding="UTF-8" standalone="no"?>'
@@ -439,7 +437,7 @@ WOK
         end
         @@xml[:open] =<<WOK
 #{encoding}
-<?xml-stylesheet type="text/css" href="../#{@env.style}/#{css}"?>
+<?xml-stylesheet type="text/css" href="../#{@env.path.style}/#{css}"?>
 #{rdf.comment_xml}
 <document>
 WOK
@@ -452,20 +450,13 @@ WOK
         @@xml[:close] = "</document>\n"
       end
       def publish
-        content=Array.new
+        content=[]
         data=@data
-        content << @@xml[:open]
-        content << @@xml[:head]
-        content << @@xml[:body]
-        content << @@xml[:metadata]
+        content << @@xml[:open] << @@xml[:head] << @@xml[:body] << @@xml[:metadata]
         content << @@xml[:owner_details] if @md.stmp =~/\w\w/
-        content << @@xml[:tail]
-        content << @@xml[:close]
+        content << @@xml[:tail] << @@xml[:close]
         Output.new(@md,content.to_s).xml
-        @@xml=Hash.new # check whether should be nil
-        #@@xml[:head]=Array.new # check whether should be nil
-        #@@xml[:body]=Array.new # check whether should be nil
-        #@@xml[:tail]=Array.new # check whether should be nil
+        @@xml={} # check whether should be nil
       end
     end
     class Output
@@ -475,7 +466,7 @@ WOK
         @md,@data=md,data
       end
       def xml
-        @sisu=Array.new
+        @sisu=[]
         @data.each do |para|
           #para.strip!
           para.gsub!(/<:\S+?>/,'')
@@ -503,14 +494,12 @@ WOK
             tell.colorize unless @md.cmd =~/q/
             tell.grey_open unless @md.cmd =~/q/
             tidyfile='/dev/null' #don't want one or screen output, check for alternative flags
-            tidy=SiSU_Env::System_call.new("#{@env.data_o}/#{@md.fnb}/#{@md.fn[:xhtml]}",tidyfile)
+            tidy=SiSU_Env::System_call.new("#{@env.path.output}/#{@md.fnb}/#{@md.fn[:xhtml]}",tidyfile)
             tidy.well_formed?
             tell.p_off unless @md.cmd =~/q/
           end
         end
       end
-      def xmlexp #possibly use to decide whether to call rexml
-      end
     end
   end
 end
