@@ -2,7 +2,7 @@
  * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
  * Author: Ralph Amissah
    * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * http://www.jus.uio.no/sisu/SiSU/download.html
 
  * Description: xml (dom style) output processing
 
@@ -56,7 +56,7 @@ module SiSU_XML_DOM
   require SiSU_lib + '/sysenv'
   include SiSU_Env
   require SiSU_lib + '/metaverse'
-  require SiSU_lib + '/common_xml'
+  require SiSU_lib + '/shared_xml'
   require SiSU_lib + '/xml_format'
   include SiSU_XML_format
   include SiSU_XML_character
@@ -72,20 +72,18 @@ module SiSU_XML_DOM
     def read
       begin
         @md=SiSU_Param::Parameters.new(@opt).get
-        @env=SiSU_Env::Info_dir.new(@opt.fns)
-        path=SiSU_Env::Info_dir.new(@opt.fns).tell_output_path
-        loc=SiSU_Env::Info_dir.new(@opt.fns).tell_output_location
-        tool=if @opt.cmd =~/[MV]/: "#{@env.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:dom]}\n\t#{@env.xml_viewer} #{path}/#{@md.fnb}/#{@md.fn[:dom]}"
-        elsif @opt.cmd =~/v/: "#{@env.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:dom]}"
+        @env=SiSU_Env::Info_env.new(@opt.fns)
+        path=@env.path.output_tell
+        loc=@env.url.output_tell
+        tool=if @opt.cmd =~/[MV]/; "#{@env.program.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:dom]}\n\t#{@env.program.xml_viewer} #{path}/#{@md.fnb}/#{@md.fn[:dom]}"
+        elsif @opt.cmd =~/v/; "#{@env.program.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:dom]}"
         else ''
         end
-        tell=SiSU_Screen::Ansi.new(@opt.cmd,'invert','XML DOM',tool)
-        tell.colorize unless @opt.cmd =~/q/
-        tell=SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.tell_output_path}/#{@md.fnb}/#{@md.fn[:dom]}")
-        tell.flow if @opt.cmd =~/[MV]/
+        SiSU_Screen::Ansi.new(@opt.cmd,'invert','XML DOM',tool).colorize unless @opt.cmd =~/q/
+        SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.path.output_tell}/#{@md.fnb}/#{@md.fn[:dom]}").flow if @opt.cmd =~/[MV]/
         @metaverse_array=SiSU_Metaverse::Source.new(@opt).get # metaverse file drawn here
         SiSU_XML_DOM::Source::Songsheet.new(@metaverse_array,@md,@env).songsheet
-      rescue: SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
         #file closed in songsheet
       end
@@ -98,49 +96,56 @@ module SiSU_XML_DOM
       def songsheet
         begin
           SiSU_XML_DOM::Source::Scroll.new(@data,@md).songsheet
-          SiSU_XML_DOM::Source::Tidy.new(@md,@env).xml if @md.cmd =~/[VM]/i # test wellformedness, comment out when not in use
+          SiSU_XML_DOM::Source::Tidy.new(@md,@env).xml if @md.cmd =~/[vVM]/ # test wellformedness, comment out when not in use
           SiSU_Rexml::Rexml.new(@md,@md.fn[:dom]).xml if @md.cmd =~/M/ # test rexml parsing, comment out when not in use #debug
-        rescue: SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
+        rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
         ensure
         end
       end
     end
     class Scroll
-      @@xml=Hash.new
-      @@xml[:body],@@xml[:open],@@xml[:close],@@xml[:head],@@xml[:sc]=Array.new,Array.new,Array.new,Array.new,Array.new
-      require SiSU_lib + '/common_text'
+      @@xml={ :body=>[],:open=>[],:close=>[],:head=>[],:sc=>[] }
+      require SiSU_lib + '/shared_txt'
       include SiSU_text_utils
       @@dp=nil
       def initialize(data='',md='')
         @data,@md=data,md
         @margin=SiSU_Viz::Margin.new
-        @@dp ||=SiSU_Env::Info_dir.new.digest_pattern
+        @@dp ||=SiSU_Env::Info_env.new.digest.pattern
         @regx=/^(?:(?:<:p[bn]>\s*)?\d~(?:(\S+))?\s+)?(.+?)\s*<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>$/ # 
         @tab="\t"
         @char_enc=SiSU_XML_character::Encode.new
         @sys=SiSU_Env::System_call.new
       end
       def songsheet
-        Scroll.new(@data,@md).pre
-        Scroll.new(@data,@md).markup
-        Scroll.new(@data,@md).post
-        Scroll.new(@data,@md).publish
+        pre
+        markup
+        post
+        publish
       end
     protected
       def xml_markup(para='')
         para.gsub!(/~\{(\d+)\s+(.+?)\s*<#{@@dp}>\}~/, 
-          "<endnote><number>\\1</number><note>\\2</note></endnote> ")
+          '<endnote><number>\1</number><note>\2</note></endnote> ')
+        para.gsub!(/~\[([*+]\d+)\s+(.+?)\s*<#{@@dp}>\]~/, 
+          '<endnote><symbol>\1</symbol><note>\2</note></endnote> ')
         para.gsub!(/~\{([*+]+)\s+(.+?)\s*<#{@@dp}>\}~/, 
-          "<endnote><asterisk>\\1</asterisk><note>\\2</note></endnote> ")
+          '<endnote><symbol>\1</symbol><note>\2</note></endnote> ')
       end
-      def xml_head(meta='',verse='')
-        verse.gsub!(/<br(?: \/)?>/,'')
-        verse.gsub!(/ & /,' and ')
-        @@xml[:head] <<<<WOK
-#{@tab}<#{meta}>
-#{@tab*2}#{verse}
-#{@tab}</#{meta}>
+      def xml_head(meta)
+        txt=meta.text
+        txt.gsub!(/<br(?: \/)?>/,'')
+        txt.gsub!(/ & /,' and ')
+        @@xml[:head] <<= if meta.type == 'meta'
+          <<WOK
+#{@tab}<header>
+#{@tab*2}<#{meta.el}>
+#{@tab*3}#{txt}
+#{@tab*2}</#{meta.el}>
+#{@tab}</header>
 WOK
+        else ''
+        end
       end
       def xml_sc(md='')
         sc=if @md.sc_info
@@ -242,19 +247,19 @@ WOK
           case lv
           when 4
             @@xml[:body] << "#{@tab*5}</content>\n" if @cont[1]
-            if @copen[3] == true # 6{
+            if @copen[3] == true # 6~
               [3,2,1].each { |v| @@xml[:body] << "#{@tab*n}</contents#{v}>\n" }
-            elsif @copen[2] == true # 5{
+            elsif @copen[2] == true # 5~
               [2,1].each { |v| @@xml[:body] << "#{@tab*n}</contents#{v}>\n" }
-            elsif @copen[1] == true # 4{ 
+            elsif @copen[1] == true # 4~ 
               [1].each { |v| @@xml[:body] << "#{@tab*n}</contents#{v}>\n" }
             end
             @cont[1]=true
           when 5
             @@xml[:body] << "#{@tab*5}</content>\n" if @cont[2] or @cont[1]
-            if @copen[3] == true  #6{
+            if @copen[3] == true  #6~
               [3,2].each { |v| @@xml[:body] << "#{@tab*n}</contents#{v}>\n" }
-            elsif @copen[2] == true #5{
+            elsif @copen[2] == true #5~
               [2].each { |v| @@xml[:body] << "#{@tab*n}</contents#{v}>\n" }
             end
             @cont[2]=true
@@ -279,11 +284,11 @@ WOK
         @@xml[:body] << "#{@tab*6}</object>" << "\n"
       end
       def poem_structure(para='',ocn='')
-        para.gsub!(/<:poem(?:-end)?>/,'')
+        para.gsub!(/<:verse(?:-end)?>/,'')
         para.strip!
         @@xml[:body] << %{#{@tab*6}<object id="#{ocn}">} << "\n"
         @@xml[:body] << %{#{@tab*7}<ocn>#{ocn}</ocn>} << "\n"
-        @@xml[:body] << %{#{@tab*7}<text class="poem">#{@tab*1}\n}
+        @@xml[:body] << %{#{@tab*7}<text class="verse">#{@tab*1}\n}
         @@xml[:body] << %{#{@tab*8}#{para}#{@tab*1}\n}
         @@xml[:body] << %{#{@tab*7}</text>\n}
         @@xml[:body] << "#{@tab*6}</object>" << "\n"
@@ -302,7 +307,7 @@ WOK
         @@xml[:body] << %{#{@tab*0}<object id="#{ocn}">} << "\n" #if para[@regx] 
         @@xml[:body] << %{#{@tab*1}#{table}\n#{@tab*1}\n} # unless lv  # main text, contents, body KEEP
         @@xml[:body] << "#{@tab*0}</object>" << "\n" #if para[@regx]
-        @endnotes=Array.new
+        @endnotes=[]
       end
       def tidywords(wordlist)
         wordlist.each do |x|
@@ -311,13 +316,10 @@ WOK
       end
       def markup
         data=@data
-        dir=SiSU_Env::Info_dir.new(@md.fns)
+        dir=SiSU_Env::Info_env.new(@md.fns)
         xml_sc(@md)
         @rcdc=false
-        @level=Array.new
-        @cont=Array.new 
-        @copen=Array.new
-        @xml_contents_close=Array.new
+        @level,@cont,@copen,@xml_contents_close=[],[],[],[]
         (0..6).each { |x| @cont[x]=@level[x]=false } 
         (4..6).each { |x| @xml_contents_close[x]='' } 
         data.each do |para|
@@ -326,15 +328,15 @@ WOK
           para.gsub!(/<[-~]#>/,'')
           para.gsub!(/<0;\w\d+;[um]\d+><#{@@dp}:#{@@dp}>/,'')
           para.gsub!(/<:pb>\s*/,'')
-          para.gsub!(/\{(\S+?\.(?:png|jpg)) .+?\}(?:(?:https?|ftp):\/\/\S+|image)/, 
-            "<image.path>#{dir.url_images_local}\/\\1</image.path>")
+          para.gsub!(/\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|ftp):\/\/\S+|image)/, 
+            "<image.path>#{dir.url.images_local}\/\\1</image.path>")
           para.gsub!(/&nbsp;/,' ') #clean
           @char_enc.utf8(para) if @sys.locale =~/utf-?8/i #% utf8
           if para =~/^0~(\S+)\s+(.+?)$/ # for headers
-            dc=SiSU_scan::Header_scan.new(@md,para).dublin
-            if dc: xml_head(dc[0],dc[1])
-	    end
-	  end
+            d_meta=SiSU_text_utils::Header_scan.new(@md,para).meta
+            if d_meta; xml_head(d_meta)
+	          end
+          end
           @rcdc=true if @rcdc==false and (para =~/~metadata/ or para =~/1~\s+Document Information/)
           if para !~/(^0~|<ENDNOTES>|<EOF>)/ 
             if para =~/.+?<~\d+;(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>.*/
@@ -372,17 +374,17 @@ WOK
                   xml_markup(para)
                   xml_structure($1,@sto.ocn,para,$2)
                   para=@sto.lev_para_ocn.heading_body6 #if para =~m
-                #when /^(i1)$/i
+                #when /^(i1)$/
                 #  #format_scroll.gsubBody
                 #  #para=@sto.lev_para_ocn.scrIndent1
-                #when /^(i2)$/i
+                #when /^(i2)$/
                 #  format_scroll.gsubBody
                 #  para=@sto.lev_para_ocn.scrIndent2
-                #when /^(center)$/i
+                #when /^(center)$/
                 #  para.gsub!(/(.+)/,
                 #    %{<center>(\\1)</center>})
                 #  para=@sto.lev_para_ocn.scrPara
-                #when /^(b|bold)$/i
+                #when /^(b|bold)$/
                 #  para.gsub!(/(.+)/,
                 #    %{<b>(\\1)</b>})
                 #  para=@sto.lev_para_ocn.scrPara
@@ -394,7 +396,7 @@ WOK
                 else
                   matched=/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#{@@dp}:#{@@dp}>$/mi.match(para)
                   stamp,ocn=matched[0],matched[1]
-                  if para =~ /<:poem>/
+                  if para =~ /<:verse>/
                     para.gsub!(/#{stamp}/,'')
                     poem_structure(para,ocn)
                   elsif para =~ /<:group>/
@@ -405,7 +407,7 @@ WOK
                     para.gsub!(/>/,'&gt;')
                     para.gsub!(/#{stamp}/,'')
                     code_structure(para,ocn)
-                  elsif para =~/<!Th?.+/i # tables come as single block #work area 2005w13
+                  elsif para =~/<!Th?.+/ # tables come as single block #work area 2005w13
                     table=SiSU_Tables::Table_xml.new(para,ocn)
                     para=table.table_split
                     @@xml[:body] << table_structure(para,ocn)
@@ -427,12 +429,12 @@ WOK
                 format_scroll=Format_scroll.new(@md,'<br /><a name="owner.details">Owner Details</a>')
                 @@xml[:owner_details]=format_scroll.bold_para
                 para=''
-              elsif para =~/(.*)<:#>(.*)/i
+              elsif para =~/(.*)<:#>(.*)/
                 one,two=$1,$2
                 format_text=Format_text_object.new(one,two)
                 para=format_text.seg_no_paranum
               end
-              para='' if (para =~/<a name="n\d+">/ and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/) # -endnote
+              para='' if para =~/<a name="n\d+">/ and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/ # -endnote
               if para =~/.*<:#>.*$/
                 para=case para
                 when /<:i1>/
@@ -446,15 +448,15 @@ WOK
               if para !~/#{@margin.txt_0}|#{@margin.txt_1}|#{@margin.txt_2}/
                 # i don't get the condition for no paranum
               end
-              if para =~/<:center>/i
-                one,two=/(.*)<:center>(.*)/i.match(para)[1,2]
+              if para =~/<:center>/
+                one,two=/(.*)<:center>(.*)/.match(para)[1,2]
                 format_text=Format_text_object.new(one,two)
                 para=format_text.center
               end
             else #
             end
             para.gsub!(/<:\S+?>/,'')
-            para.gsub!(/<!.+!>/i,' ') ## Clean Prepared Text
+            para.gsub!(/<!.+!>/,' ') ## Clean Prepared Text
           end
         end
         @content_flag=true
@@ -477,20 +479,14 @@ WOK
       end
       def pre
         rdf=SiSU_XML_tags::RDF.new(@md)
-        dir=SiSU_Env::Info_dir.new
-        #<?xml version="1.0"?>
-        #<?xml version="1.0" encoding="UTF-8" standalone="no"?>
-        #<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>
-        #<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
-        #<?xml version="1.0" encoding="UTF-8" standalone="no"?>
-        #<?xml version="1.0" encoding="UTF-16" standalone="no"?>
+        dir=SiSU_Env::Info_env.new
         css=SiSU_Env::CSS_select.new(@md).xml_dom
-        encoding=if @sys.locale =~/utf-?8/i: '<?xml version="1.0" encoding="UTF-8" standalone="no"?>'
+        encoding=if @sys.locale =~/utf-?8/i; '<?xml version="1.0" encoding="UTF-8" standalone="no"?>'
         else                                 '<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>'
         end
         @@xml[:open] =<<WOK
 #{encoding}
-<?xml-stylesheet type="text/css" href="../#{dir.style}/#{css}"?>
+<?xml-stylesheet type="text/css" href="../#{dir.path.style}/#{css}"?>
 #{rdf.comment_xml}
 <document>
 WOK
@@ -504,19 +500,13 @@ WOK
         @@xml[:close] = "</document>\n"
       end
       def publish
-        content=Array.new
+        content=[]
         data=@data
-        content << @@xml[:open]
-        content << @@xml[:head]
-        content << @@xml[:body]
-        content << @@xml[:metadata]
+        content << @@xml[:open] << @@xml[:head] << @@xml[:body] << @@xml[:metadata]
         content << @@xml[:owner_details] if @md.stmp =~/\w\w/
-        content << @@xml[:tail]
-        content << @@xml[:close]
+        content << @@xml[:tail] << @@xml[:close]
         Output.new(content.to_s,@md).xml
-        @@xml[:head]=Array.new # check whether should be nil
-        @@xml[:body]=Array.new # check whether should be nil
-        @@xml[:tail]=Array.new # check whether should be nil
+        @@xml[:head],@@xml[:body],@@xml[:tail]=[],[],[] # check whether should be nil
       end
     end
     class Output
@@ -525,7 +515,7 @@ WOK
         @data,@md=data,md
       end
       def xml
-        @sisu=Array.new
+        @sisu=[]
         @data.each do |para| #p
           #para.strip!
           para.gsub!(/<:\S+?>/,'')
@@ -554,7 +544,7 @@ WOK
             tell.colorize unless @md.cmd =~/q/
             tell.grey_open unless @md.cmd =~/q/
             tidyfile='/dev/null' #don't want one or screen output, check for alternative flags
-            tidy=SiSU_Env::System_call.new("#{@env.data_o}/#{@md.fnb}/#{@md.fn[:dom]}",tidyfile)
+            tidy=SiSU_Env::System_call.new("#{@env.path.output}/#{@md.fnb}/#{@md.fn[:dom]}",tidyfile)
             tidy.well_formed?
             tell.p_off unless @md.cmd =~/q/
           end
